* {
    background-clip: padding-box;
    -GtkToolButton-icon-spacing: 1px;
    -GtkTextView-error-underline-color: @error_color;
    -GtkScrolledWindow-scrollbar-spacing: 0;
	-GtkScrolledWindow-scrollbars-within-bevel: 1px;
    -GtkToolItemGroup-expander-size: 10px;
    -GtkTreeView-expander-size: 10px;
    -GtkTreeView-horizontal-separator: 4;
    -GtkWidget-text-handle-width: 20;
    -GtkWidget-text-handle-height: 20;
    -GtkDialog-button-spacing: 4;
    -GtkDialog-action-area-border: 2px;
	-GtkScrollbar-activate-slider: 1;
    color: @theme_text_color;
	-GtkWindow-resize-grip-default: false;
	-GtkScrollbar-has-backward-stepper: 1;
    -GtkScrollbar-has-forward-stepper: 1; 
}

.background {
    background-color: @theme_bg_color;
    color: @theme_fg_color;
}

*:disabled {
    -gtk-icon-effect: dim; }

.gtkstyle-fallback {
    background-color: #383C4A;
    color: #D3DAE3; }
.gtkstyle-fallback:hover {
    background-color: #4e5467;
    color: #D3DAE3; }
.gtkstyle-fallback:active {
    background-color: #22242d;
    color: #D3DAE3; }
.gtkstyle-fallback:disabled {
    background-color: #3c4150;
    color: rgba(211, 218, 227, 0.45); }
.gtkstyle-fallback:selected {
    background-color: @theme_selected_bg_color;
    color: #ffffff; }

.view, iconview,
.view text,
iconview text,
textview text {
    color: @theme_fg_color;
    background-color: @theme_base_color; }
.view:selected, iconview:selected, .view:selected:focus, iconview:selected:focus,
.view text:selected,
iconview text:selected,
textview text:selected,
.view text:selected:focus,
iconview text:selected:focus,
textview text:selected:focus {
    border-radius: 2px; }

textview border {
    background-color: @theme_bg_color; }

rubberband, flowbox rubberband, treeview.view rubberband, .content-view rubberband,
.rubberband {
    background-color: @theme_selected_bg_color;
    border-color: @theme_selected_bg_color;
  	border: 1px solid #b8383e;
}

flowbox flowboxchild {
    padding: 3px;
    border-radius: 2px; }
flowbox flowboxchild:selected {
    outline-offset: -2px; }

label.separator, popover label.separator,
popover.background label.separator {
    color: #D3DAE3; }

label selection {
    color: #ffffff;
    background-color: @theme_selected_bg_color; }

label:disabled {
    color: rgba(211, 218, 227, 0.45); }

.dim-label, label.separator, popover label.separator,
popover.background label.separator, headerbar .subtitle, .titlebar:not(headerbar) .subtitle {
    opacity: 0.55; }

assistant .sidebar {
    background-color: @theme_bg_color;
    border-top: 1px solid #2b2e39; }

assistant.csd .sidebar {
    border-top-style: none; }

assistant .sidebar label {
    padding: 6px 12px; }

assistant .sidebar label.highlight {
    background-color: @theme_selected_bg_color;
    color: #ffffff; }

textview {
    background-color: @theme_bg_color; }

popover.osd, popover.magnifier, .csd popover.osd, .csd popover.magnifier,
popover.background.osd,
popover.background.magnifier, .csd popover.background.osd, .csd popover.background.magnifier, .osd .scale-popup, .osd {
    color: #BAC3CF;
    border: none;
    background-color: rgba(53, 57, 69, 0.95);
    background-clip: padding-box;
    outline-color: rgba(186, 195, 207, 0.3);
    box-shadow: none; }

@keyframes spin {
    to {
        -gtk-icon-transform: rotate(1turn); } }

spinner {
    background: none;
    opacity: 0;
    -gtk-icon-source: -gtk-icontheme("process-working-symbolic"); }
spinner:checked {
    opacity: 1;
    animation: spin 1s linear infinite; }
spinner:checked:disabled {
    opacity: 0.5; }

entry {
    padding: 5px;
    caret-color: @entry_text_color;
    transition: all 200ms cubic-bezier(0.25, 0.46, 0.45, 0.94);

	background-color: @theme_base_color;
    border: 1px #3D3D3D solid;
    /* we use inner-border instead of padding because padding
     * also applies to the progressbar.
     */
    padding: 4px 3px;
    color: @entry_text_color;
    }
entry.search {

}
entry image {
    color: #b6bcc6; 
}
entry image.left {
    padding-left: 0;
    padding-right: 5px; }
entry image.right {
    padding-right: 0;
    padding-left: 5px; }
entry.flat, entry.flat:focus {
    min-height: 0;
    padding: 2px;
    background-image: none;
    border-color: transparent;
    border-radius: 0; }
entry:focus {
    background-clip: border-box;
	background-color: @theme_selected_bg_color;
	color: @theme_selected_fg_color;
}
entry:disabled {
    color: rgba(211, 218, 227, 0.45);
    border-color: rgba(43, 46, 57, 0.55);
    background-color: rgba(64, 69, 82, 0.55);
    background-image: linear-gradient(to bottom, rgba(64, 69, 82, 0.55)); }
entry.warning {
    color: #ffffff;
    border-color: #2b2e39;
    background-image: linear-gradient(to bottom, #ab6441); }
entry.warning image {
    color: #ffffff; }
entry.warning:focus {
    color: #ffffff;
    background-image: linear-gradient(to bottom, #F27835);
    box-shadow: none; }
entry.warning selection, entry.warning selection:focus {
    background-color: #ffffff;
    color: #F27835; }
entry.error {
    color: #ffffff;
    border-color: #2b2e39;
    background-image: linear-gradient(to bottom, #b14342); }
entry.error image {
    color: #ffffff; }
entry.error:focus {
    color: #ffffff;
    background-image: linear-gradient(to bottom, #FC4138);
    box-shadow: none; }
entry.error selection, entry.error selection:focus {
    background-color: #ffffff;
    color: #FC4138; }
entry.search-missing {
    color: #ffffff;
    border-color: #2b2e39;
    background-image: linear-gradient(to bottom, #b14342); }
entry.search-missing image {
    color: #ffffff; }
entry.search-missing:focus {
    color: #ffffff;
    background-image: linear-gradient(to bottom, #FC4138);
    box-shadow: none; }
entry.search-missing selection, entry.search-missing selection:focus {
    background-color: #ffffff;
    color: #FC4138; }
entry:drop(active):focus, entry:drop(active) {
    border-color: #F08437;
    box-shadow: none; }

entry progress {
    background-color: @theme_selected_bg_color;
    color: @theme_selected_fg_color;

    border-width: 1px; 
}

.osd entry {
    color: #BAC3CF;
    border-color: rgba(26, 28, 34, 0.35);
    background-image: linear-gradient(to bottom, rgba(102, 109, 132, 0.35));
    background-color: transparent; }
.osd entry image, .osd entry image:hover {
    color: inherit; }
.osd entry:focus {
    color: #ffffff;
    border-color: rgba(26, 28, 34, 0.35);
    background-image: linear-gradient(to bottom, @theme_selected_bg_color); }
.osd entry:disabled {
    color: rgba(186, 195, 207, 0.55);
    background-image: linear-gradient(to bottom, rgba(102, 109, 132, 0.2)); }
.osd entry selection:focus, .osd entry selection {
    color: @theme_selected_bg_color;
    background-color: #ffffff; }


treeview entry.flat, treeview entry {
    border-radius: 0;
    background-image: none;
    background-color: @theme_bg_color; }
treeview entry.flat:focus, treeview entry:focus {
    border-color: @theme_selected_bg_color; }

@keyframes needs_attention {
    from {
        background-image: -gtk-gradient(radial, center center, 0, center center, 0.01, to(@theme_selected_bg_color), to(transparent)); }
    to {
        background-image: -gtk-gradient(radial, center center, 0, center center, 0.5, to(@theme_selected_bg_color), to(transparent)); } }

button {
    color: @internal_element_color;
    border: solid;
    background-image: url("darkelements/button-normal.png");
    border-image: url("darkelements/button-normal-border.png") 2 2 2 2 / 2px 2px 2px 2px stretch stretch;
    border-width:2px;
    background-size: 100% 100%;
}
button separator {
    margin: 4px 1px; }
button.flat, button.sidebar-button {
    border-color: transparent;
    background-color: transparent;
    background-image: none;
    transition: none; }
button.flat:hover, button.sidebar-button:hover {
    transition: all 200ms cubic-bezier(0.25, 0.46, 0.45, 0.94);
    transition-duration: 350ms; }
button.flat:hover:active, button.sidebar-button:hover:active {
    transition: all 200ms cubic-bezier(0.25, 0.46, 0.45, 0.94); }

button:hover,
button:active, button:checked{
    background-color: @theme_base_color;
	border: solid;
    color: @theme_text_color;
    background-image: url("darkelements/button-normal.png");
    border-image: url("darkelements/button-normal-border.png") 2 2 2 2 / 2px 2px 2px 2px stretch stretch;
    border-width:2px;
	background-size: 100% 100%;
}

button.flat:disabled, button.sidebar-button:disabled {
    border-color: transparent;
    background-color: transparent;
    background-image: none; }
button:disabled {
    background-color: @theme_base_color;
	border: solid;
    color: @theme_text_color;
    background-image: url("darkelements/button-insensitive.png");
    border-image: url("darkelements/button-normal-border.png") 2 2 2 2 / 2px 2px 2px 2px stretch stretch;
    border-width:2px;
	background-size: 100% 100%;   
}

button.image-button {
    min-width: 24px;
    padding-left: 5px;
    padding-right: 5px; }
button.text-button {
    padding-left: 12px;
    padding-right: 12px; }
button.text-button.image-button {
    padding-left: 5px;
    padding-right: 5px; }
button.text-button.image-button label:first-child {
    padding-left: 8px;
    padding-right: 2px; }
button.text-button.image-button label:last-child {
    padding-right: 8px;
    padding-left: 2px; }
button.text-button.image-button label:only-child {
    padding-left: 8px;
    padding-right: 8px; }
button.text-button.image-button.popup {
    padding-right: 8px;
    padding-left: 8px; }
button:drop(active), combobox:drop(active) button.combo {
}
button.osd {
    color: #BAC3CF;
    outline-color: rgba(186, 195, 207, 0.3);
    background-color: rgba(53, 57, 69, 0.95);
    border-color: rgba(35, 38, 46, 0.95); }
button.osd.image-button {
    padding: 0;
    min-height: 36px;
    min-width: 36px; }
button.osd:hover {
    color: @theme_selected_bg_color; }
button.osd:active, button.osd:checked {
    color: #ffffff;
    outline-color: rgba(255, 255, 255, 0.3);
    border-color: rgba(26, 28, 34, 0.35);
    background-color: @theme_selected_bg_color; }
button.osd:disabled {
    color: #5d626e;
    border-color: rgba(26, 28, 34, 0.35);
    background-color: rgba(102, 109, 132, 0.2); }
.osd button {
    color: #BAC3CF;
    outline-color: rgba(186, 195, 207, 0.3);
    border-color: rgba(26, 28, 34, 0.35);
    background-color: rgba(102, 109, 132, 0.35); }
.osd button:hover {
    color: #BAC3CF;
    outline-color: rgba(186, 195, 207, 0.3);
    border-color: rgba(26, 28, 34, 0.35);
    background-color: rgba(119, 127, 151, 0.45); }
.osd button:active, .osd button:checked {
    background-clip: padding-box;
    color: #ffffff;
    outline-color: rgba(255, 255, 255, 0.3);
    border-color: rgba(26, 28, 34, 0.35);
    background-color: @theme_selected_bg_color; }
.osd button:disabled {
    color: #5d626e;
    border-color: rgba(26, 28, 34, 0.35);
    background-color: rgba(102, 109, 132, 0.2); }
.osd button.flat, .osd button.sidebar-button {
    border-color: transparent;
    background-color: transparent;
    background-image: none;
    box-shadow: none; }
.osd button.flat:hover, .osd button.sidebar-button:hover {
    color: #BAC3CF;
    outline-color: rgba(186, 195, 207, 0.3);
    border-color: rgba(26, 28, 34, 0.35);
    background-color: rgba(119, 127, 151, 0.45); }
.osd button.flat:disabled, .osd button.sidebar-button:disabled {
    color: #5d626e;
    border-color: rgba(26, 28, 34, 0.35);
    background-color: rgba(102, 109, 132, 0.2);
    background-image: none; }
.osd button.flat:active, .osd button.sidebar-button:active, .osd button.flat:checked, .osd button.sidebar-button:checked {
    color: #ffffff;
    outline-color: rgba(255, 255, 255, 0.3);
    border-color: rgba(26, 28, 34, 0.35);
    background-color: @theme_selected_bg_color; }
.osd .linked:not(.vertical):not(.path-bar) > button:hover:not(:checked):not(:active):not(:only-child),
.osd .linked:not(.vertical):not(.path-bar) > button:hover:not(:checked):not(:active) + button:not(:checked):not(:active) {
    box-shadow: none; }
button.suggested-action {
    background-clip: border-box;
    color: #ffffff;
    outline-color: rgba(255, 255, 255, 0.3);
    background-color: #be3941;
    border-color: #be3941; }
button.suggested-action.flat, button.suggested-action.sidebar-button {
    border-color: transparent;
    background-color: transparent;
    background-image: none;
    color: #be3941;
    outline-color: rgba(190, 57, 65, 0.3); }
button.suggested-action:hover {
    background-clip: border-box;
    color: #ffffff;
    outline-color: rgba(255, 255, 255, 0.3);
    background-color: #ce5c63;
    border-color: #ce5c63; }
button.suggested-action:active, button.suggested-action:checked {
    background-clip: border-box;
    color: #ffffff;
    outline-color: rgba(255, 255, 255, 0.3);
    background-color: #972d34;
    border-color: #972d34; }
button.suggested-action.flat:disabled, button.suggested-action.sidebar-button:disabled {
    border-color: transparent;
    background-color: transparent;
    background-image: none;
    color: rgba(211, 218, 227, 0.45); }
button.suggested-action:disabled {
    border-color: rgba(43, 46, 57, 0.55);
    background-color: rgba(68, 74, 88, 0.55); }
button.suggested-action:disabled label, button.suggested-action:disabled {
    color: rgba(211, 218, 227, 0.45); }
button.destructive-action {
    background-clip: border-box;
    color: #ffffff;
    outline-color: rgba(255, 255, 255, 0.3);
    background-color: #F04A50;
    border-color: #F04A50; }
button.destructive-action.flat, button.destructive-action.sidebar-button {
    border-color: transparent;
    background-color: transparent;
    background-image: none;
    color: #F04A50;
    outline-color: rgba(240, 74, 80, 0.3); }
button.destructive-action:hover {
    background-clip: border-box;
    color: #ffffff;
    outline-color: rgba(255, 255, 255, 0.3);
    background-color: #f4797e;
    border-color: #f4797e; }
button.destructive-action:active, button.destructive-action:checked {
    background-clip: border-box;
    color: #ffffff;
    outline-color: rgba(255, 255, 255, 0.3);
    background-color: #ec1b22;
    border-color: #ec1b22; }
button.destructive-action.flat:disabled, button.destructive-action.sidebar-button:disabled {
    border-color: transparent;
    background-color: transparent;
    background-image: none;
    color: rgba(211, 218, 227, 0.45); }
button.destructive-action:disabled {
    border-color: rgba(43, 46, 57, 0.55);
    background-color: rgba(68, 74, 88, 0.55); }
button.destructive-action:disabled label, button.destructive-action:disabled {
    color: rgba(211, 218, 227, 0.45); }

combobox arrow {
  	-gtk-icon-source: -gtk-icontheme("pan-down-symbolic");
  	min-height: 16px;
	min-width: 16px; 
}
combobox button.combo{
    padding: 3px;
    color: @theme_text_color;
	border: solid;
    background-image: url("darkelements/button-normal.png");
    border-image: url("darkelements/button-normal-border.png") 2 2 2 2 / 2px 2px 2px 2px stretch stretch;
    border-width:2px;
	background-size: 100% 100%;
	background-color: transparent;
}
.button:active,
.button:hover,
combobox button.combo:hover{
    /*transition: 50ms ease-in-out;   */
	border: solid;
    background-image: url("darkelements/button-hover.png");
    border-image: url("darkelements/button-hover-border.png") 2 2 2 2 / 2px 2px 2px 2px stretch stretch;
    border-width:2px;
	background-size: 100% 100%;
}

.button:insensitive,
combobox button.combo:insensitive {
	border: solid;
    background-image: url("darkelements/column-header.png");
    border-image: url("darkelements/button-normal-border.png") 2 2 2 2 / 2px 2px 2px 2px stretch stretch;
    border-width:2px;
    background-color: @insensitive_bg_color;
    color: @insensitive_fg_color;
	background-size: 100% 100%;
	border-width: 2px;
	border-color:transparent;

}
.stack-switcher > button {
    outline-offset: -3px; }
.stack-switcher > button > label {
    padding-left: 6px;
    padding-right: 6px; }
.stack-switcher > button > image {
    padding-left: 6px;
    padding-right: 6px;
    padding-top: 3px;
    padding-bottom: 3px; }
.stack-switcher > button.text-button {
    padding-left: 10px;
    padding-right: 10px; }
.stack-switcher > button.image-button {
    padding-left: 2px;
    padding-right: 2px; }
.stack-switcher > button.needs-attention:active > label, .stack-switcher > button.needs-attention:active > image, .stack-switcher > button.needs-attention:checked > label, .stack-switcher > button.needs-attention:checked > image {
    animation: none;
    background-image: none; }
.stack-switcher > button.needs-attention > label, .stack-switcher > button.needs-attention > image, button stacksidebar row.needs-attention > label, stacksidebar button row.needs-attention > label {
    animation: needs_attention 150ms ease-in;
    background-image: -gtk-gradient(radial, center center, 0, center center, 0.5, to(@theme_selected_bg_color), to(transparent));
    background-size: 6px 6px, 6px 6px;
    background-repeat: no-repeat;
    background-position: right 3px, right 2px; }
.stack-switcher > button.needs-attention > label:dir(rtl), .stack-switcher > button.needs-attention > image:dir(rtl), button stacksidebar row.needs-attention > label:dir(rtl), stacksidebar button row.needs-attention > label:dir(rtl) {
    background-position: left 3px, left 2px; }
.inline-toolbar button, .inline-toolbar button:backdrop {
    border-radius: 2px;
    border-width: 1px; }

.inline-toolbar toolbutton > button {
    color: #D3DAE3;
    outline-color: rgba(211, 218, 227, 0.3);
    border-color: #2b2e39;
    background-color: #444a58; }
.inline-toolbar toolbutton > button:hover {
    color: #D3DAE3;
    outline-color: rgba(211, 218, 227, 0.3);
    border-color: #2b2e39;
    background-color: #505666; }
.inline-toolbar toolbutton > button:active, .inline-toolbar toolbutton > button:checked {
    color: #ffffff;
    outline-color: rgba(255, 255, 255, 0.3);
    border-color: #2b2e39;
    background-color: @theme_selected_bg_color; }
.inline-toolbar toolbutton > button:disabled {
    border-color: rgba(43, 46, 57, 0.55);
    background-color: rgba(68, 74, 88, 0.55); }
.inline-toolbar toolbutton > button:disabled label, .inline-toolbar toolbutton > button:disabled {
    color: rgba(211, 218, 227, 0.45); }
.inline-toolbar toolbutton > button:disabled:active, .inline-toolbar toolbutton > button:disabled:checked {
    border-color: rgba(204, 87, 93, 0.75);
    background-color: rgba(204, 87, 93, 0.75);
    opacity: 0.6; }
.inline-toolbar toolbutton > button:disabled:active label, .inline-toolbar toolbutton > button:disabled:active, .inline-toolbar toolbutton > button:disabled:checked label, .inline-toolbar toolbutton > button:disabled:checked {
    color: rgba(255, 255, 255, 0.8); }

.linked:not(.vertical):not(.path-bar) > entry + entry {
    border-left-color: rgba(43, 46, 57, 0.3); }

.linked:not(.vertical):not(.path-bar) > entry.error + entry,
.linked:not(.vertical):not(.path-bar) > entry + entry.error {
    border-left-color: rgba(43, 46, 57, 0.3); }

.linked:not(.vertical):not(.path-bar) > entry.warning + entry,
.linked:not(.vertical):not(.path-bar) > entry + entry.warning {
    border-left-color: rgba(43, 46, 57, 0.3); }

.linked:not(.vertical):not(.path-bar) > entry.error + entry.warning,
.linked:not(.vertical):not(.path-bar) > entry.warning + entry.error {
    border-left-color: rgba(43, 46, 57, 0.3); }

.linked:not(.vertical):not(.path-bar) > entry + entry:focus:not(:last-child),
.linked:not(.vertical):not(.path-bar) > entry + entry:focus:last-child {
    border-left-color: #2b2e39; }

.linked:not(.vertical):not(.path-bar) > entry:focus:not(:only-child) + entry,
.linked:not(.vertical):not(.path-bar) > entry:focus:not(:only-child) + button,
.linked:not(.vertical):not(.path-bar) > entry:focus:not(:only-child) + combobox > box > button.combo {
    border-left-color: #2b2e39; }

.linked:not(.vertical):not(.path-bar) > entry + entry:drop(active):not(:last-child),
.linked:not(.vertical):not(.path-bar) > entry + entry:drop(active):last-child {
    border-left-color: #2b2e39; }

.linked:not(.vertical):not(.path-bar) > entry:drop(active):not(:only-child) + entry,
.linked:not(.vertical):not(.path-bar) > entry:drop(active):not(:only-child) + button,
.linked:not(.vertical):not(.path-bar) > entry:drop(active):not(:only-child) + combobox > box > button.combo {
    border-left-color: #2b2e39; }

.linked:not(.vertical):not(.path-bar) > entry + entry.warning:focus:not(:last-child),
.linked:not(.vertical):not(.path-bar) > entry + entry.warning:focus:last-child {
    border-left-color: #2b2e39; }

.linked:not(.vertical):not(.path-bar) > entry.warning:focus:not(:only-child) + entry,
.linked:not(.vertical):not(.path-bar) > entry.warning:focus:not(:only-child) + button,
.linked:not(.vertical):not(.path-bar) > entry.warning:focus:not(:only-child) + combobox > box > button.combo {

}

.linked:not(.vertical):not(.path-bar) > entry + entry.error:focus:not(:last-child),
.linked:not(.vertical):not(.path-bar) > entry + entry.error:focus:last-child {
    border-left-color: #2b2e39; }

.linked:not(.vertical):not(.path-bar) > entry.error:focus:not(:only-child) + entry,
.linked:not(.vertical):not(.path-bar) > entry.error:focus:not(:only-child) + button,
.linked:not(.vertical):not(.path-bar) > entry.error:focus:not(:only-child) + combobox > box > button.combo {
    border-left-color: #2b2e39; }

.linked:not(.vertical):not(.path-bar) > button:active + entry,
.linked:not(.vertical):not(.path-bar) > button:checked + entry {
    border-left-color: #2b2e39; }

.linked:not(.vertical):not(.path-bar) > button + button {
    border-left-style: none; }

.linked:not(.vertical):not(.path-bar) > button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):hover:not(:only-child),
.linked:not(.vertical):not(.path-bar) > button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):hover + button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action) {
    box-shadow: inset 1px 0 #2b2e39; }

.linked:not(.vertical):not(.path-bar) > button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):first-child:hover,
.linked:not(.vertical):not(.path-bar) > button:active + button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):hover,
.linked:not(.vertical):not(.path-bar) > button:checked + button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):hover,
.linked:not(.vertical):not(.path-bar) > button.suggested-action + button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):hover,
.linked:not(.vertical):not(.path-bar) > button.destructive-action + button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):hover,
.linked:not(.vertical):not(.path-bar) > entry + button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):hover:not(:only-child) {
    box-shadow: none; }

.linked:not(.vertical).path-bar > button + button {
    border-left-style: none; }

.linked:not(.vertical).path-bar > button:hover:not(:checked):not(:active):not(:only-child):hover {
    box-shadow: inset 1px 0 rgba(43, 46, 57, 0.5), inset -1px 0 rgba(43, 46, 57, 0.5); }

.linked:not(.vertical).path-bar > button:hover:not(:checked):not(:active):not(:only-child):first-child:hover {
    box-shadow: inset -1px 0 rgba(43, 46, 57, 0.5); }

.linked:not(.vertical).path-bar > button:hover:not(:checked):not(:active):not(:only-child):last-child:hover {
    box-shadow: inset 1px 0 rgba(43, 46, 57, 0.5); }

.linked.vertical > entry + entry {
    border-top-color: rgba(43, 46, 57, 0.3); }

.linked.vertical > entry.error + entry,
.linked.vertical > entry + entry.error {
    border-top-color: rgba(43, 46, 57, 0.3); }

.linked.vertical > entry.warning + entry,
.linked.vertical > entry + entry.warning {
    border-top-color: rgba(43, 46, 57, 0.3); }

.linked.vertical > entry.error + entry.warning,
.linked.vertical > entry.warning + entry.error {
    border-top-color: rgba(43, 46, 57, 0.3); }

.linked.vertical > entry + entry:focus:not(:last-child),
.linked.vertical > entry + entry:focus:last-child {
    border-top-color: #2b2e39; }

.linked.vertical > entry:focus:not(:only-child) + entry,
.linked.vertical > entry:focus:not(:only-child) + button,
.linked.vertical > entry:focus:not(:only-child) + combobox > box > button.combo {
    border-top-color: #2b2e39; }

.linked.vertical > entry + entry:drop(active):not(:last-child),
.linked.vertical > entry + entry:drop(active):last-child {

}

.linked.vertical > entry:drop(active):not(:only-child) + entry,
.linked.vertical > entry:drop(active):not(:only-child) + button,
.linked.vertical > entry:drop(active):not(:only-child) + combobox > box > button.combo {

}

.linked.vertical > entry + entry.warning:focus:not(:last-child),
.linked.vertical > entry + entry.warning:focus:last-child {
    border-top-color: #2b2e39; }

.linked.vertical > entry.warning:focus:not(:only-child) + entry,
.linked.vertical > entry.warning:focus:not(:only-child) + button,
.linked.vertical > entry.warning:focus:not(:only-child) + combobox > box > button.combo {

}

.linked.vertical > entry + entry.error:focus:not(:last-child),
.linked.vertical > entry + entry.error:focus:last-child {
    border-top-color: #2b2e39; }

.linked.vertical > entry.error:focus:not(:only-child) + entry,
.linked.vertical > entry.error:focus:not(:only-child) + button,
.linked.vertical > entry.error:focus:not(:only-child) + combobox > box > button.combo {

}

.linked.vertical > button:active + entry,
.linked.vertical > button:checked + entry {
    border-top-color: #2b2e39; }

.linked.vertical > button + button {
    border-top-style: none; }

.linked.vertical > button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):hover:not(:only-child),
.linked.vertical > button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):hover + button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action) {
    box-shadow: inset 0 1px #2b2e39; }

.linked.vertical > button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):first-child:hover,
.linked.vertical > button:active + button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):hover,
.linked.vertical > button:checked + button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):hover,
.linked.vertical > button.suggested-action + button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):hover,
.linked.vertical > button.destructive-action + button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):hover,
.linked.vertical > entry + button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):hover:not(:only-child) {
    box-shadow: none; }

toolbar.inline-toolbar toolbutton > button.flat, .inline-toolbar toolbutton > button.flat, toolbar.inline-toolbar toolbutton > button.sidebar-button, .inline-toolbar toolbutton > button.sidebar-button, .linked:not(.vertical) > entry,
.linked:not(.vertical) > entry:focus, .inline-toolbar button, .inline-toolbar button:backdrop, .linked:not(.vertical) > button,
.linked:not(.vertical) > button:hover,
.linked:not(.vertical) > button:active,
.linked:not(.vertical) > button:checked, spinbutton:not(.vertical) button, spinbutton:not(.vertical) entry, .primary-toolbar .linked:not(.vertical):not(.path-bar).stack-switcher > button, headerbar .linked:not(.vertical):not(.path-bar).stack-switcher > button, .primary-toolbar .linked:not(.vertical):not(.path-bar).stack-switcher > button:hover, headerbar .linked:not(.vertical):not(.path-bar).stack-switcher > button:hover, .primary-toolbar .linked:not(.vertical):not(.path-bar).stack-switcher > button:active, headerbar .linked:not(.vertical):not(.path-bar).stack-switcher > button:active, .primary-toolbar .linked:not(.vertical):not(.path-bar).stack-switcher > button:checked, headerbar .linked:not(.vertical):not(.path-bar).stack-switcher > button:checked, .primary-toolbar .linked:not(.vertical):not(.path-bar).stack-switcher > button:disabled, headerbar .linked:not(.vertical):not(.path-bar).stack-switcher > button:disabled, .primary-toolbar .linked:not(.vertical).path-bar > button, headerbar .linked:not(.vertical).path-bar > button, .primary-toolbar .linked:not(.vertical).path-bar > button:hover, headerbar .linked:not(.vertical).path-bar > button:hover, .primary-toolbar .linked:not(.vertical).path-bar > button:active, headerbar .linked:not(.vertical).path-bar > button:active, .primary-toolbar .linked:not(.vertical).path-bar > button:checked, headerbar .linked:not(.vertical).path-bar > button:checked, .primary-toolbar .linked:not(.vertical).path-bar > button:disabled, headerbar .linked:not(.vertical).path-bar > button:disabled, .nemo-window .primary-toolbar widget.raised.linked:not(.vertical):not(.path-bar) > button, .nemo-window .primary-toolbar widget.raised.linked:not(.vertical):not(.path-bar) > button:hover, .nemo-window .primary-toolbar widget.raised.linked:not(.vertical):not(.path-bar) > button:active, .nemo-window .primary-toolbar widget.raised.linked:not(.vertical):not(.path-bar) > button:checked, .nemo-window .primary-toolbar widget.raised.linked:not(.vertical):not(.path-bar) > button:disabled, .linked:not(.vertical) > combobox > box > button.combo:dir(ltr), .linked:not(.vertical) > combobox > box > button.combo:dir(rtl) {
    border-radius: 0;
    border-right-style: none; }

.linked:not(.vertical) > entry:first-child, .inline-toolbar button:first-child, .linked:not(.vertical) > button:first-child, toolbar.inline-toolbar toolbutton:first-child > button.flat, .inline-toolbar toolbutton:first-child > button.flat, toolbar.inline-toolbar toolbutton:first-child > button.sidebar-button, .inline-toolbar toolbutton:first-child > button.sidebar-button, spinbutton:not(.vertical) button:first-child, spinbutton:not(.vertical) entry:first-child, .linked:not(.vertical) > combobox:first-child > box > button.combo, .primary-toolbar .linked:not(.vertical):not(.path-bar).stack-switcher > button:first-child, headerbar .linked:not(.vertical):not(.path-bar).stack-switcher > button:first-child, .primary-toolbar .linked:not(.vertical).path-bar > button:first-child, headerbar .linked:not(.vertical).path-bar > button:first-child, .nemo-window .primary-toolbar widget.raised.linked:not(.vertical):not(.path-bar) > button:first-child {
    border-top-left-radius: 3px;
    border-bottom-left-radius: 3px; }

.linked:not(.vertical) > entry:last-child, .inline-toolbar button:last-child, .linked:not(.vertical) > button:last-child, toolbar.inline-toolbar toolbutton:last-child > button.flat, .inline-toolbar toolbutton:last-child > button.flat, toolbar.inline-toolbar toolbutton:last-child > button.sidebar-button, .inline-toolbar toolbutton:last-child > button.sidebar-button, spinbutton:not(.vertical) button:last-child, spinbutton:not(.vertical) entry:last-child, .linked:not(.vertical) > combobox:last-child > box > button.combo, .primary-toolbar .linked:not(.vertical):not(.path-bar).stack-switcher > button:last-child, headerbar .linked:not(.vertical):not(.path-bar).stack-switcher > button:last-child, .primary-toolbar .linked:not(.vertical).path-bar > button:last-child, headerbar .linked:not(.vertical).path-bar > button:last-child, .nemo-window .primary-toolbar widget.raised.linked:not(.vertical):not(.path-bar) > button:last-child {
    border-top-right-radius: 3px;
    border-bottom-right-radius: 3px;
    border-right-style: solid; }

.linked:not(.vertical) > entry:only-child, .inline-toolbar button:only-child, .linked:not(.vertical) > button:only-child, toolbar.inline-toolbar toolbutton:only-child > button.flat, .inline-toolbar toolbutton:only-child > button.flat, toolbar.inline-toolbar toolbutton:only-child > button.sidebar-button, .inline-toolbar toolbutton:only-child > button.sidebar-button, spinbutton:not(.vertical) button:only-child, spinbutton:not(.vertical) entry:only-child, .linked:not(.vertical) > combobox:only-child > box > button.combo, .primary-toolbar .linked:not(.vertical):not(.path-bar).stack-switcher > button:only-child, headerbar .linked:not(.vertical):not(.path-bar).stack-switcher > button:only-child, .primary-toolbar .linked:not(.vertical).path-bar > button:only-child, headerbar .linked:not(.vertical).path-bar > button:only-child, .nemo-window .primary-toolbar widget.raised.linked:not(.vertical):not(.path-bar) > button:only-child {
    border-radius: 3px;
    border-style: solid; }

.linked.vertical > entry,
.linked.vertical > entry:focus, .linked.vertical > button,
.linked.vertical > button:hover,
.linked.vertical > button:active,
.linked.vertical > button:checked, spinbutton.vertical button, spinbutton.vertical entry, .linked.vertical > combobox > box > button.combo {
    border-radius: 0;
    border-bottom-style: none; }

.linked.vertical > entry:first-child, .linked.vertical > button:first-child, spinbutton.vertical button:first-child, spinbutton.vertical entry:first-child, .linked.vertical > combobox:first-child > box > button.combo {
    border-top-left-radius: 3px;
    border-top-right-radius: 3px; }

.linked.vertical > entry:last-child, .linked.vertical > button:last-child, spinbutton.vertical button:last-child, spinbutton.vertical entry:last-child, .linked.vertical > combobox:last-child > box > button.combo {
    border-bottom-left-radius: 3px;
    border-bottom-right-radius: 3px;
    border-bottom-style: solid; }

.linked.vertical > entry:only-child, .linked.vertical > button:only-child, spinbutton.vertical button:only-child, spinbutton.vertical entry:only-child, .linked.vertical > combobox:only-child > box > button.combo {
    border-radius: 3px;
    border-style: solid; }

menuitem.button.flat,
modelbutton.flat, button:link, button:visited, button:link:hover, button:link:active, button:link:checked, button:visited:hover, button:visited:active, button:visited:checked, notebook > header > tabs > tab button.flat:hover, notebook > header > tabs > tab button.sidebar-button:hover, notebook > header > tabs > tab button.flat:active, notebook > header > tabs > tab button.sidebar-button:active, notebook > header > tabs > tab button.flat:active:hover, notebook > header > tabs > tab button.sidebar-button:active:hover, .app-notification button.flat, .app-notification button.sidebar-button, .app-notification button.flat:disabled, .app-notification button.sidebar-button:disabled {
    border-color: transparent;
    background-color: transparent;
    background-image: none;
    box-shadow: none; }

menuitem.button.flat,
modelbutton.flat {
    transition: none;
    min-height: 24px;
    padding-left: 8px;
    padding-right: 8px;
    outline-offset: -3px;
    border-radius: 2px; }
menuitem.button.flat:hover,
modelbutton.flat:hover {
    background-color: #484c59; }
menuitem.button.flat:checked,
modelbutton.flat:checked {
    color: #D3DAE3; }
menuitem.button.flat check:last-child,
menuitem.button.flat radio:last-child,
modelbutton.flat check:last-child,
modelbutton.flat radio:last-child {
    margin-left: 8px; }
menuitem.button.flat check:first-child,
menuitem.button.flat radio:first-child,
modelbutton.flat check:first-child,
modelbutton.flat radio:first-child {
    margin-right: 8px; }

modelbutton.flat arrow.left {
    -gtk-icon-source: -gtk-icontheme("pan-start-symbolic"); }

modelbutton.flat arrow.right {
    -gtk-icon-source: -gtk-icontheme("pan-end-symbolic"); }

*:link, button:link, button:visited {
    color: #e4a5a8; }
*:link:visited, button:visited {
    color: #d87e83; }
*:selected *:link:visited, *:selected button:visited:link, *:selected button:visited {
    color: #ebbcbe; }
*:link:hover, button:hover:link, button:hover:visited {
    color: #f0ccce; }
*:selected *:link:hover, *:selected button:hover:link, *:selected button:hover:visited {
    color: #faeeef; }
*:link:active, button:active:link, button:active:visited {
    color: #e4a5a8; }
*:selected *:link:active, *:selected button:active:link, *:selected button:active:visited {
    color: #f5dddf; }
.info *:link, .info button:link, .info button:visited,
.question *:link,
.question button:link,
.question button:visited,
.warning *:link,
.warning button:link,
.warning button:visited,
.error *:link,
.error button:link,
.error button:visited, *:link:selected, button:selected:link, button:selected:visited, headerbar.selection-mode .subtitle:link, .selection-mode.titlebar:not(headerbar) .subtitle:link,
*:selected *:link,
*:selected button:link,
*:selected button:visited {
    color: #f5dddf; }

button:link > label, button:visited > label {
    text-decoration-line: underline; }

spinbutton:drop(active) {
    box-shadow: none; }

spinbutton button:active {
    color: #ffffff; }

spinbutton:disabled {
    color: rgba(211, 218, 227, 0.45); }

spinbutton:not(.vertical) entry {
    min-width: 28px; }

spinbutton:not(.vertical):dir(ltr) entry,
spinbutton:not(.vertical):dir(rtl) button.up {
    border-radius: 3px 0 0 3px; }

spinbutton:not(.vertical) > button + button {
    border-left-style: none; }

spinbutton:not(.vertical) > button:hover:not(:active),
spinbutton:not(.vertical) > button:hover + button {
    box-shadow: inset 1px 0 #2b2e39; }

spinbutton:not(.vertical) > button:first-child:hover:not(:active),
spinbutton:not(.vertical) > button.up:dir(rtl):hover:not(:active),
spinbutton:not(.vertical) > entry + button:not(:active):hover {
    box-shadow: none; }

spinbutton:not(.vertical) > entry:focus + button {
    border-left-color: #2b2e39; }

spinbutton:not(.vertical) > entry:drop(active) + button {
    border-left-color: #F08437; }

.osd spinbutton:not(.vertical) > button:hover:not(:active),
.osd spinbutton:not(.vertical) > button:hover + button {
    box-shadow: inset 1px 0 rgba(26, 28, 34, 0.35); }

.osd spinbutton:not(.vertical) > button:first-child:hover:not(:active),
.osd spinbutton:not(.vertical) > button.up:dir(rtl):hover:not(:active),
.osd spinbutton:not(.vertical) > entry + button:not(:active):hover {
    box-shadow: none; }

.osd spinbutton:not(.vertical) > entry:focus + button {
    border-left-color: rgba(26, 28, 34, 0.35); }

spinbutton.vertical button, spinbutton.vertical entry {
    padding-left: 4px;
    padding-right: 4px;
    min-width: 0; }

spinbutton.vertical button.up {
    border-radius: 3px 3px 0 0; }

spinbutton.vertical > entry:focus + button {
    border-top-color: #2b2e39; }

spinbutton.vertical > entry:drop(active) + button {
    border-top-color: #F08437; }

combobox button.combo {
    min-width: 0;
    padding-left: 8px;
    padding-right: 8px; }

combobox arrow {
    -gtk-icon-source: -gtk-icontheme("pan-down-symbolic");
    min-height: 16px;
    min-width: 16px; }

toolbar, .inline-toolbar {

}
toolbar separator, .inline-toolbar separator {
    background: none; }
toolbar.horizontal separator, .horizontal.inline-toolbar separator {

}
toolbar.vertical separator, .vertical.inline-toolbar separator {


}
.osd toolbar, .osd .inline-toolbar {
    background-color: transparent; }
toolbar.osd, .osd.inline-toolbar {
}
toolbar.osd.left, .osd.left.inline-toolbar, toolbar.osd.right, .osd.right.inline-toolbar, toolbar.osd.top, .osd.top.inline-toolbar, toolbar.osd.bottom, .osd.bottom.inline-toolbar {
    border-radius: 0; }
toolbar.osd.top, .osd.top.inline-toolbar {
    border-width: 0 0 1px 0; }
toolbar.osd.bottom, .osd.bottom.inline-toolbar {
}
toolbar.osd.left, .osd.left.inline-toolbar {
 }
toolbar.osd.right, .osd.right.inline-toolbar {
; }
toolbar:not(.inline-toolbar) switch, .inline-toolbar:not(.inline-toolbar) switch,
toolbar:not(.inline-toolbar) scale, .inline-toolbar:not(.inline-toolbar) scale,
toolbar:not(.inline-toolbar) entry, .inline-toolbar:not(.inline-toolbar) entry,
toolbar:not(.inline-toolbar) spinbutton, .inline-toolbar:not(.inline-toolbar) spinbutton,
toolbar:not(.inline-toolbar) button, .inline-toolbar:not(.inline-toolbar) button {

}
toolbar:not(.inline-toolbar) .linked > button, .inline-toolbar:not(.inline-toolbar) .linked > button,
toolbar:not(.inline-toolbar) .linked > entry, .inline-toolbar:not(.inline-toolbar) .linked > entry {
    margin-right: 0; }

.primary-toolbar separator,
separator.vertical,
separator.vertical:hover,
separator.vertical:backdrop,
separator.vertical:hover:backdrop {
	border:solid;
    background-image: url("darkelements/line-v.png");
	background-size: 100% 100%;
    border-image: url("darkelements/line-v.png") 0 2 0 0 / 0 2px 0 0 stretch ;
    border-width:2px;
    
    color: alpha(#ffffff, 0.1);
}
toolbar .button {
    padding: 2px 5px;
	background-color: transparent;
}
.primary-toolbar {
    background-image: url("darkelements/toolbar.png");
    padding:3px;
    border-style: solid;
    border-color: #3A3A3A;
    border-width: 0 0 1px 0;
    border-radius: 0;
    border-image-width: 0;
}

.inline-toolbar {
    border-width: 0;
    border-image: none;
    border-color:@theme_bg_color;
	background-image: url("darkelements/toolbar.png");
	background-size: 100% 100%
}

/* primary toolbar buttons */
.primary-toolbar .button,
.primary-toolbar.button {
    background-color: transparent;
    border-style: solid;
	border-color: transparent;
    border-image:none;
	background-image:none;

    border-width: 2px;
}

searchbar {
    background-color: #383C4A;
    border-style: solid;
    border-color: #2b2e39;
    border-width: 0 0 1px;
    padding: 3px; }




actionbar {
    padding: 6px;
    border-top: 1px solid #2b2e39;
    background-color: #313541; }

headerbar {
	background-color: #000000;
	background-size: 100% 100%;
	border: solid;
    background-image: url("darkelements/tab-top.png");
    padding-left: 5px;
    padding-right: 5px
	border-radius: 0;
}

headerbar,
.titlebar:not(headerbar) {
    min-height: 32px;
    padding: 0 5px;
    border-width: 0 0 1px;
    border-style: solid;
    border-color: #262a33;
    color: rgba(207, 218, 231, 0.8);
    background-color: #2f343f;
    box-shadow: inset 0 1px rgba(54, 59, 72, 0.97); }
.csd headerbar,
.csd .titlebar:not(headerbar) {
    background-color: rgba(47, 52, 63, 0.97);
    border-color: rgba(38, 42, 51, 0.97); }
headerbar:backdrop,
.titlebar:backdrop:not(headerbar) {
    transition: 200ms ease-out;
    color: rgba(207, 218, 231, 0.5);
    background-color: #323843; }
.csd headerbar:backdrop,
.csd .titlebar:backdrop:not(headerbar) {
    background-color: rgba(50, 56, 67, 0.97); }
headerbar .title, .titlebar:not(headerbar) .title {
    padding-left: 12px;
    padding-right: 12px; }
headerbar .subtitle, .titlebar:not(headerbar) .subtitle {
    font-size: smaller;
    padding-left: 12px;
    padding-right: 12px; }
headerbar.selection-mode,
.selection-mode.titlebar:not(headerbar) {
    color: #ffffff;
    background-color: rgba(204, 87, 93, 0.95);
    border-color: rgba(199, 71, 78, 0.95);
    box-shadow: none; }
headerbar.selection-mode:backdrop,
.selection-mode.titlebar:backdrop:not(headerbar) {
    background-color: rgba(204, 87, 93, 0.95);
    color: rgba(255, 255, 255, 0.6); }
headerbar.selection-mode .selection-menu, .selection-mode.titlebar:not(headerbar) .selection-menu {
    box-shadow: none;
    padding-left: 10px;
    padding-right: 10px; }
headerbar.selection-mode .selection-menu GtkArrow, .selection-mode.titlebar:not(headerbar) .selection-menu GtkArrow {
    -GtkArrow-arrow-scaling: 0.4; }
headerbar.selection-mode .selection-menu .arrow, .selection-mode.titlebar:not(headerbar) .selection-menu .arrow {
    -gtk-icon-source: -gtk-icontheme("pan-down-symbolic"); }
.maximized headerbar.selection-mode,
.maximized .selection-mode.titlebar:not(headerbar) {
    background-color: @theme_selected_bg_color; }
.tiled headerbar, .tiled headerbar:backdrop,
.maximized headerbar, .maximized headerbar:backdrop,
.tiled .titlebar:not(headerbar),
.tiled .titlebar:backdrop:not(headerbar),
.maximized .titlebar:not(headerbar),
.maximized .titlebar:backdrop:not(headerbar) {
    border-radius: 0; }
.maximized headerbar,
.maximized .titlebar:not(headerbar) {
    background-color: #2f343f;
    border-color: #262a33; }
.maximized headerbar:backdrop,
.maximized .titlebar:backdrop:not(headerbar) {
    background-color: #323843; }
headerbar.default-decoration,
.csd headerbar.default-decoration, headerbar.default-decoration:backdrop,
.csd headerbar.default-decoration:backdrop,
.default-decoration.titlebar:not(headerbar),
.csd .default-decoration.titlebar:not(headerbar),
.default-decoration.titlebar:backdrop:not(headerbar),
.csd .default-decoration.titlebar:backdrop:not(headerbar) {
    min-height: 28px;
    padding: 0 3px;
    background-color: #2f343f;
    border-bottom-width: 0; }
.maximized headerbar.default-decoration, .maximized
.csd headerbar.default-decoration, .maximized headerbar.default-decoration:backdrop, .maximized
.csd headerbar.default-decoration:backdrop,
.maximized .default-decoration.titlebar:not(headerbar),
.maximized
.csd .default-decoration.titlebar:not(headerbar),
.maximized .default-decoration.titlebar:backdrop:not(headerbar),
.maximized
.csd .default-decoration.titlebar:backdrop:not(headerbar) {
    background-color: #2f343f; }

.titlebar {
    border-radius: 3px 3px 0 0; }

headerbar entry, headerbar button, headerbar separator {
    margin-top: 6px;
    margin-bottom: 6px; }

separator:first-child + headerbar, separator:first-child + headerbar:backdrop, headerbar:first-child, headerbar:first-child:backdrop {
    border-top-left-radius: 3px; }
.maximized separator:first-child + headerbar,
.tiled separator:first-child + headerbar, .maximized separator:first-child + headerbar:backdrop,
.tiled separator:first-child + headerbar:backdrop, .maximized headerbar:first-child,
.tiled headerbar:first-child, .maximized headerbar:first-child:backdrop,
.tiled headerbar:first-child:backdrop {
    border-radius: 0; }

headerbar:last-child, headerbar:last-child:backdrop {
    border-top-right-radius: 3px; }
.maximized headerbar:last-child,
.tiled headerbar:last-child, .maximized headerbar:last-child:backdrop,
.tiled headerbar:last-child:backdrop {
    border-radius: 0; }

window > .titlebar:not(headerbar), window > .titlebar:not(headerbar):backdrop,
window.csd > .titlebar:not(headerbar),
window.csd > .titlebar:not(headerbar):backdrop {
    padding: 0;
    background: none;
    border: none;
    box-shadow: none; }

.titlebar:not(headerbar) > separator {
    background-image: linear-gradient(to top, rgba(38, 42, 51, 0.97)); }

.primary-toolbar separator, headerbar separator.titlebutton, .titlebar:not(headerbar) separator.titlebutton {
    min-width: 1px;
    min-height: 1px;
    background: none;
    border-width: 0 1px;
    border-image: linear-gradient(to bottom, rgba(207, 218, 231, 0) 25%, rgba(207, 218, 231, 0.15) 25%, rgba(207, 218, 231, 0.15) 75%, rgba(207, 218, 231, 0) 75%) 0 1/0 1px stretch; }
.primary-toolbar separator:backdrop, headerbar separator.titlebutton:backdrop, .titlebar:not(headerbar) separator.titlebutton:backdrop {
}

.primary-toolbar entry, headerbar entry {
    color: rgba(207, 218, 231, 0.8);
    border-color: rgba(21, 23, 28, 0.37);
    background-image: linear-gradient(to bottom, rgba(95, 105, 127, 0.37));
    background-color: transparent; }
.primary-toolbar entry image, headerbar entry image, .primary-toolbar entry image:hover, headerbar entry image:hover {
    color: inherit; }
.primary-toolbar entry:backdrop, headerbar entry:backdrop {
    opacity: 0.85; }
.primary-toolbar entry:focus, headerbar entry:focus {
    color: #ffffff;
    border-color: transparent;
    background-image: linear-gradient(to bottom, @theme_selected_bg_color);
    background-clip: padding-box; }
.primary-toolbar entry:focus image, headerbar entry:focus image {
    color: #ffffff; }
.primary-toolbar entry:disabled, headerbar entry:disabled {
    color: rgba(207, 218, 231, 0.35);
    background-image: linear-gradient(to bottom, rgba(95, 105, 127, 0.22)); }
.primary-toolbar entry selection:focus, headerbar entry selection:focus {
    background-color: #ffffff;
    color: @theme_selected_bg_color; }
.primary-toolbar entry progress, headerbar entry progress {
    border-color: @theme_selected_bg_color;
    background-image: none;
    background-color: transparent; }
.primary-toolbar entry.warning, headerbar entry.warning {
    color: #ffffff;
    border-color: rgba(21, 23, 28, 0.37);
    background-image: linear-gradient(to bottom, rgba(167, 94, 57, 0.988)); }
.primary-toolbar entry.warning:focus, headerbar entry.warning:focus {
    color: #ffffff;
    background-image: linear-gradient(to bottom, #F27835); }
.primary-toolbar entry.warning selection, headerbar entry.warning selection, .primary-toolbar entry.warning selection:focus, headerbar entry.warning selection:focus {
    background-color: #ffffff;
    color: #F27835; }
.primary-toolbar entry.error, headerbar entry.error {
    color: #ffffff;
    border-color: rgba(21, 23, 28, 0.37);
    background-image: linear-gradient(to bottom, rgba(173, 60, 59, 0.988)); }
.primary-toolbar entry.error:focus, headerbar entry.error:focus {
    color: #ffffff;
    background-image: linear-gradient(to bottom, #FC4138); }
.primary-toolbar entry.error selection, headerbar entry.error selection, .primary-toolbar entry.error selection:focus, headerbar entry.error selection:focus {
    background-color: #ffffff;
    color: #FC4138; }

.primary-toolbar button, headerbar button {
	background-color: transparent;
    border-style: solid;
	border-color: transparent;
    border-image:none;
	background-image:none;

    border-width: 2px;
}
.primary-toolbar button:backdrop, headerbar button:backdrop {
    opacity: 0.7; }
.primary-toolbar button:hover, headerbar button:hover {
	border: solid;
    background-image: url("darkelements/button-hover.png");
    border-image: url("darkelements/button-hover-border.png") 2 2 2 2 / 2px 2px 2px 2px stretch stretch;
    border-width: 2px;
    color: @theme_text_color;
	background-size: 100% 100
}
.primary-toolbar button:active, headerbar button:active, .primary-toolbar button:checked, headerbar button:checked {
border: solid;
    background-image: url("darkelements/button-hover.png");
    border-image: url("darkelements/button-hover-border.png") 2 2 2 2 / 2px 2px 2px 2px stretch stretch;
    border-width: 2px;
    color: @theme_text_color;
	background-size: 100% 100%;    
}
.primary-toolbar button:disabled, headerbar button:disabled {
    background-color: rgba(47, 52, 63, 0);
    border-color: rgba(47, 52, 63, 0); }
.primary-toolbar button:disabled label, headerbar button:disabled label, .primary-toolbar button:disabled, headerbar button:disabled {
    color: rgba(207, 218, 231, 0.35); }
.primary-toolbar button:disabled:active, headerbar button:disabled:active, .primary-toolbar button:disabled:checked, headerbar button:disabled:checked {
    color: rgba(255, 255, 255, 0.75);
    border-color: rgba(204, 87, 93, 0.65);
    background-color: rgba(204, 87, 93, 0.65); }

.selection-mode.primary-toolbar button, headerbar.selection-mode button, .selection-mode.primary-toolbar button.flat, headerbar.selection-mode button.flat, .selection-mode.primary-toolbar button.sidebar-button, headerbar.selection-mode button.sidebar-button {
    border-color: transparent;
    background-color: transparent;
    background-image: none;
    color: #ffffff;
    background-color: rgba(255, 255, 255, 0); }

.primary-toolbar .linked:not(.vertical):not(.path-bar):not(.stack-switcher) button:not(:last-child):not(:only-child), headerbar .linked:not(.vertical):not(.path-bar):not(.stack-switcher) button:not(:last-child):not(:only-child) {
    margin-right: 1px; }

.primary-toolbar .linked:not(.vertical):not(.path-bar) > button, headerbar .linked:not(.vertical):not(.path-bar) > button, .primary-toolbar .linked:not(.vertical):not(.path-bar) > button:hover, headerbar .linked:not(.vertical):not(.path-bar) > button:hover, .primary-toolbar .linked:not(.vertical):not(.path-bar) > button:active, headerbar .linked:not(.vertical):not(.path-bar) > button:active, .primary-toolbar .linked:not(.vertical):not(.path-bar) > button:checked, headerbar .linked:not(.vertical):not(.path-bar) > button:checked, .primary-toolbar .linked:not(.vertical):not(.path-bar) > button:disabled, headerbar .linked:not(.vertical):not(.path-bar) > button:disabled {
    border-radius: 3px;
    border-style: solid; }

.primary-toolbar .linked:not(.vertical):not(.path-bar) > button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):hover:not(:only-child), headerbar .linked:not(.vertical):not(.path-bar) > button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):hover:not(:only-child), .primary-toolbar .linked:not(.vertical):not(.path-bar) > button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):hover + button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action), headerbar .linked:not(.vertical):not(.path-bar) > button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action):hover + button:not(:checked):not(:active):not(.suggested-action):not(.destructive-action) {
    box-shadow: none; }

.primary-toolbar .linked:not(.vertical):not(.path-bar).stack-switcher > button, headerbar .linked:not(.vertical):not(.path-bar).stack-switcher > button, .primary-toolbar .linked:not(.vertical).path-bar > button, headerbar .linked:not(.vertical).path-bar > button {
    color: rgba(207, 218, 231, 0.8);
    outline-color: rgba(207, 218, 231, 0.1);
    border-color: rgba(21, 23, 28, 0.37);
    background-color: rgba(95, 105, 127, 0.37); }
.primary-toolbar .linked:not(.vertical):not(.path-bar).stack-switcher > button:hover, headerbar .linked:not(.vertical):not(.path-bar).stack-switcher > button:hover, .primary-toolbar .linked:not(.vertical).path-bar > button:hover, headerbar .linked:not(.vertical).path-bar > button:hover {
    background-color: rgba(134, 144, 165, 0.37); }
.primary-toolbar .linked:not(.vertical):not(.path-bar).stack-switcher > button:active, headerbar .linked:not(.vertical):not(.path-bar).stack-switcher > button:active, .primary-toolbar .linked:not(.vertical):not(.path-bar).stack-switcher > button:checked, headerbar .linked:not(.vertical):not(.path-bar).stack-switcher > button:checked, .primary-toolbar .linked:not(.vertical).path-bar > button:active, headerbar .linked:not(.vertical).path-bar > button:active, .primary-toolbar .linked:not(.vertical).path-bar > button:checked, headerbar .linked:not(.vertical).path-bar > button:checked {
    color: #ffffff;
    outline-color: rgba(255, 255, 255, 0.3);
    border-color: transparent;
    background-color: @theme_selected_bg_color; }
.primary-toolbar .linked:not(.vertical):not(.path-bar).stack-switcher > button:disabled, headerbar .linked:not(.vertical):not(.path-bar).stack-switcher > button:disabled, .primary-toolbar .linked:not(.vertical).path-bar > button:disabled, headerbar .linked:not(.vertical).path-bar > button:disabled {
    color: rgba(207, 218, 231, 0.4); }

.primary-toolbar .linked:not(.vertical):not(.path-bar).stack-switcher > button + button, headerbar .linked:not(.vertical):not(.path-bar).stack-switcher > button + button, .primary-toolbar .linked:not(.vertical).path-bar > button + button, headerbar .linked:not(.vertical).path-bar > button + button {
    border-left-style: none; }

.primary-toolbar .linked:not(.vertical):not(.path-bar).stack-switcher > button:hover:not(:checked):not(:active):not(:only-child):hover, headerbar .linked:not(.vertical):not(.path-bar).stack-switcher > button:hover:not(:checked):not(:active):not(:only-child):hover, .primary-toolbar .linked:not(.vertical).path-bar > button:hover:not(:checked):not(:active):not(:only-child):hover, headerbar .linked:not(.vertical).path-bar > button:hover:not(:checked):not(:active):not(:only-child):hover {
    box-shadow: inset 1px 0 rgba(21, 23, 28, 0.37), inset -1px 0 rgba(21, 23, 28, 0.37); }

.primary-toolbar .linked:not(.vertical):not(.path-bar).stack-switcher > button:hover:not(:checked):not(:active):not(:only-child):first-child:hover, headerbar .linked:not(.vertical):not(.path-bar).stack-switcher > button:hover:not(:checked):not(:active):not(:only-child):first-child:hover, .primary-toolbar .linked:not(.vertical).path-bar > button:hover:not(:checked):not(:active):not(:only-child):first-child:hover, headerbar .linked:not(.vertical).path-bar > button:hover:not(:checked):not(:active):not(:only-child):first-child:hover {
    box-shadow: inset -1px 0 rgba(21, 23, 28, 0.37); }

.primary-toolbar .linked:not(.vertical):not(.path-bar).stack-switcher > button:hover:not(:checked):not(:active):not(:only-child):last-child:hover, headerbar .linked:not(.vertical):not(.path-bar).stack-switcher > button:hover:not(:checked):not(:active):not(:only-child):last-child:hover, .primary-toolbar .linked:not(.vertical).path-bar > button:hover:not(:checked):not(:active):not(:only-child):last-child:hover, headerbar .linked:not(.vertical).path-bar > button:hover:not(:checked):not(:active):not(:only-child):last-child:hover {
    box-shadow: inset 1px 0 rgba(21, 23, 28, 0.37); }

.primary-toolbar .linked:not(.vertical):not(.path-bar) > entry + entry, headerbar .linked:not(.vertical):not(.path-bar) > entry + entry {
    border-left-color: rgba(21, 23, 28, 0); }

.primary-toolbar .linked:not(.vertical):not(.path-bar) > entry.error + entry, headerbar .linked:not(.vertical):not(.path-bar) > entry.error + entry, .primary-toolbar .linked:not(.vertical):not(.path-bar) > entry + entry.error, headerbar .linked:not(.vertical):not(.path-bar) > entry + entry.error {
    border-left-color: rgba(21, 23, 28, 0); }

.primary-toolbar .linked:not(.vertical):not(.path-bar) > entry.warning + entry, headerbar .linked:not(.vertical):not(.path-bar) > entry.warning + entry, .primary-toolbar .linked:not(.vertical):not(.path-bar) > entry + entry.warning, headerbar .linked:not(.vertical):not(.path-bar) > entry + entry.warning {
    border-left-color: rgba(21, 23, 28, 0); }

.primary-toolbar .linked:not(.vertical):not(.path-bar) > entry.error + entry.warning, headerbar .linked:not(.vertical):not(.path-bar) > entry.error + entry.warning, .primary-toolbar .linked:not(.vertical):not(.path-bar) > entry.warning + entry.error, headerbar .linked:not(.vertical):not(.path-bar) > entry.warning + entry.error {
    border-left-color: rgba(21, 23, 28, 0); }

.primary-toolbar .linked:not(.vertical):not(.path-bar) > entry + entry:focus:not(:last-child), headerbar .linked:not(.vertical):not(.path-bar) > entry + entry:focus:not(:last-child), .primary-toolbar .linked:not(.vertical):not(.path-bar) > entry + entry:focus:last-child, headerbar .linked:not(.vertical):not(.path-bar) > entry + entry:focus:last-child {
    border-left-color: rgba(21, 23, 28, 0.37); }

.primary-toolbar .linked:not(.vertical):not(.path-bar) > entry:focus:not(:only-child) + entry, headerbar .linked:not(.vertical):not(.path-bar) > entry:focus:not(:only-child) + entry, .primary-toolbar .linked:not(.vertical):not(.path-bar) > entry:focus:not(:only-child) + button, headerbar .linked:not(.vertical):not(.path-bar) > entry:focus:not(:only-child) + button, .primary-toolbar .linked:not(.vertical):not(.path-bar) > entry:focus:not(:only-child) + combobox > box > button.combo, headerbar .linked:not(.vertical):not(.path-bar) > entry:focus:not(:only-child) + combobox > box > button.combo {
    border-left-color: rgba(21, 23, 28, 0.37); }

.primary-toolbar .linked:not(.vertical):not(.path-bar) > entry + entry:drop(active):not(:last-child), headerbar .linked:not(.vertical):not(.path-bar) > entry + entry:drop(active):not(:last-child), .primary-toolbar .linked:not(.vertical):not(.path-bar) > entry + entry:drop(active):last-child, headerbar .linked:not(.vertical):not(.path-bar) > entry + entry:drop(active):last-child {
    border-left-color: rgba(21, 23, 28, 0.37); }

.primary-toolbar .linked:not(.vertical):not(.path-bar) > entry:drop(active):not(:only-child) + entry, headerbar .linked:not(.vertical):not(.path-bar) > entry:drop(active):not(:only-child) + entry, .primary-toolbar .linked:not(.vertical):not(.path-bar) > entry:drop(active):not(:only-child) + button, headerbar .linked:not(.vertical):not(.path-bar) > entry:drop(active):not(:only-child) + button, .primary-toolbar .linked:not(.vertical):not(.path-bar) > entry:drop(active):not(:only-child) + combobox > box > button.combo, headerbar .linked:not(.vertical):not(.path-bar) > entry:drop(active):not(:only-child) + combobox > box > button.combo {
    border-left-color: rgba(21, 23, 28, 0.37); }

.primary-toolbar .linked:not(.vertical):not(.path-bar) > entry + entry.warning:focus:not(:last-child), headerbar .linked:not(.vertical):not(.path-bar) > entry + entry.warning:focus:not(:last-child), .primary-toolbar .linked:not(.vertical):not(.path-bar) > entry + entry.warning:focus:last-child, headerbar .linked:not(.vertical):not(.path-bar) > entry + entry.warning:focus:last-child {
    border-left-color: rgba(21, 23, 28, 0.37); }

.primary-toolbar .linked:not(.vertical):not(.path-bar) > entry.warning:focus:not(:only-child) + entry, headerbar .linked:not(.vertical):not(.path-bar) > entry.warning:focus:not(:only-child) + entry, .primary-toolbar .linked:not(.vertical):not(.path-bar) > entry.warning:focus:not(:only-child) + button, headerbar .linked:not(.vertical):not(.path-bar) > entry.warning:focus:not(:only-child) + button, .primary-toolbar .linked:not(.vertical):not(.path-bar) > entry.warning:focus:not(:only-child) + combobox > box > button.combo, headerbar .linked:not(.vertical):not(.path-bar) > entry.warning:focus:not(:only-child) + combobox > box > button.combo {
    border-left-color: rgba(21, 23, 28, 0.37); }

.primary-toolbar .linked:not(.vertical):not(.path-bar) > entry + entry.error:focus:not(:last-child), headerbar .linked:not(.vertical):not(.path-bar) > entry + entry.error:focus:not(:last-child), .primary-toolbar .linked:not(.vertical):not(.path-bar) > entry + entry.error:focus:last-child, headerbar .linked:not(.vertical):not(.path-bar) > entry + entry.error:focus:last-child {
    border-left-color: rgba(21, 23, 28, 0.37); }

.primary-toolbar .linked:not(.vertical):not(.path-bar) > entry.error:focus:not(:only-child) + entry, headerbar .linked:not(.vertical):not(.path-bar) > entry.error:focus:not(:only-child) + entry, .primary-toolbar .linked:not(.vertical):not(.path-bar) > entry.error:focus:not(:only-child) + button, headerbar .linked:not(.vertical):not(.path-bar) > entry.error:focus:not(:only-child) + button, .primary-toolbar .linked:not(.vertical):not(.path-bar) > entry.error:focus:not(:only-child) + combobox > box > button.combo, headerbar .linked:not(.vertical):not(.path-bar) > entry.error:focus:not(:only-child) + combobox > box > button.combo {
    border-left-color: rgba(21, 23, 28, 0.37); }

.primary-toolbar .linked:not(.vertical):not(.path-bar) > button:active + entry, headerbar .linked:not(.vertical):not(.path-bar) > button:active + entry, .primary-toolbar .linked:not(.vertical):not(.path-bar) > button:checked + entry, headerbar .linked:not(.vertical):not(.path-bar) > button:checked + entry {
    border-left-color: rgba(21, 23, 28, 0.37); }

.primary-toolbar button.suggested-action, headerbar button.suggested-action {

}
.primary-toolbar button.suggested-action.flat, headerbar button.suggested-action.flat, .primary-toolbar button.suggested-action.sidebar-button, headerbar button.suggested-action.sidebar-button {

}
.primary-toolbar button.suggested-action:hover, headerbar button.suggested-action:hover {

}
.primary-toolbar button.suggested-action:active, headerbar button.suggested-action:active, .primary-toolbar button.suggested-action:checked, headerbar button.suggested-action:checked {

}
.primary-toolbar button.suggested-action.flat:disabled, headerbar button.suggested-action.flat:disabled, .primary-toolbar button.suggested-action.sidebar-button:disabled, headerbar button.suggested-action.sidebar-button:disabled, .primary-toolbar button.suggested-action:disabled, headerbar button.suggested-action:disabled {

}
.primary-toolbar button.suggested-action.flat:disabled label, headerbar button.suggested-action.flat:disabled label, .primary-toolbar button.suggested-action.sidebar-button:disabled label, headerbar button.suggested-action.sidebar-button:disabled label, .primary-toolbar button.suggested-action.flat:disabled, headerbar button.suggested-action.flat:disabled, .primary-toolbar button.suggested-action.sidebar-button:disabled, headerbar button.suggested-action.sidebar-button:disabled, .primary-toolbar button.suggested-action:disabled label, headerbar button.suggested-action:disabled label, .primary-toolbar button.suggested-action:disabled, headerbar button.suggested-action:disabled {

}

.primary-toolbar button.suggested-action:backdrop, headerbar button.suggested-action:backdrop, .primary-toolbar button.suggested-action:backdrop, headerbar button.suggested-action:backdrop {

}

.primary-toolbar button.destructive-action, headerbar button.destructive-action {

}
.primary-toolbar button.destructive-action.flat, headerbar button.destructive-action.flat, .primary-toolbar button.destructive-action.sidebar-button, headerbar button.destructive-action.sidebar-button {

}
.primary-toolbar button.destructive-action:hover, headerbar button.destructive-action:hover {

}
.primary-toolbar button.destructive-action:active, headerbar button.destructive-action:active, .primary-toolbar button.destructive-action:checked, headerbar button.destructive-action:checked {

}
.primary-toolbar button.destructive-action.flat:disabled, headerbar button.destructive-action.flat:disabled, .primary-toolbar button.destructive-action.sidebar-button:disabled, headerbar button.destructive-action.sidebar-button:disabled, .primary-toolbar button.destructive-action:disabled, headerbar button.destructive-action:disabled {

}
.primary-toolbar button.destructive-action.flat:disabled label, headerbar button.destructive-action.flat:disabled label, .primary-toolbar button.destructive-action.sidebar-button:disabled label, headerbar button.destructive-action.sidebar-button:disabled label, .primary-toolbar button.destructive-action.flat:disabled, headerbar button.destructive-action.flat:disabled, .primary-toolbar button.destructive-action.sidebar-button:disabled, headerbar button.destructive-action.sidebar-button:disabled, .primary-toolbar button.destructive-action:disabled label, headerbar button.destructive-action:disabled label, .primary-toolbar button.destructive-action:disabled, headerbar button.destructive-action:disabled {

}

.primary-toolbar button.destructive-action:backdrop, headerbar button.destructive-action:backdrop, .primary-toolbar button.destructive-action:backdrop, headerbar button.destructive-action:backdrop {

}

.primary-toolbar spinbutton:not(.vertical):focus, headerbar spinbutton:not(.vertical):focus {
    color: @theme_selected_fg_color;
    caret-color: @theme_selected_fg_color; }

.primary-toolbar spinbutton:not(.vertical) button, headerbar spinbutton:not(.vertical) button, .primary-toolbar spinbutton:not(.vertical) button:disabled, headerbar spinbutton:not(.vertical) button:disabled {

}

.primary-toolbar spinbutton:not(.vertical) button:hover, headerbar spinbutton:not(.vertical) button:hover {

}

.primary-toolbar spinbutton:not(.vertical) button:active, headerbar spinbutton:not(.vertical) button:active, .primary-toolbar spinbutton:not(.vertical) button:checked, headerbar spinbutton:not(.vertical) button:checked {

}

.primary-toolbar spinbutton:not(.vertical) button:disabled, headerbar spinbutton:not(.vertical) button:disabled {

}

.primary-toolbar spinbutton:not(.vertical) > button + button, headerbar spinbutton:not(.vertical) > button + button {
    border-left-style: none; 
}

.primary-toolbar spinbutton:not(.vertical) > button:hover:not(:active), headerbar spinbutton:not(.vertical) > button:hover:not(:active), .primary-toolbar spinbutton:not(.vertical) > button:hover + button, headerbar spinbutton:not(.vertical) > button:hover + button {
    box-shadow: inset 2px 0 #000000;
}

.primary-toolbar spinbutton:not(.vertical) > button:first-child:hover:not(:active), headerbar spinbutton:not(.vertical) > button:first-child:hover:not(:active), .primary-toolbar spinbutton:not(.vertical) > entry + button:not(:active):hover, headerbar spinbutton:not(.vertical) > entry + button:not(:active):hover {
    box-shadow: none; 
}

.primary-toolbar spinbutton:not(.vertical) > entry:focus + button, headerbar spinbutton:not(.vertical) > entry:focus + button {

}

.primary-toolbar combobox:disabled, headerbar combobox:disabled {
    color: gray; 

}

.primary-toolbar combobox > .linked > button.combo, headerbar combobox > .linked > button.combo {
    color: @theme_selected_fg_color;
    border-color: rgba(21, 23, 28, 0.37);
    background-image: linear-gradient(to bottom, rgba(95, 105, 127, 0.37));
    background-color: transparent; 
}
.primary-toolbar combobox > .linked > button.combo image, headerbar combobox > .linked > button.combo image, .primary-toolbar combobox > .linked > button.combo image:hover, headerbar combobox > .linked > button.combo image:hover {
    color: inherit; 
}
.primary-toolbar combobox > .linked > button.combo:hover, headerbar combobox > .linked > button.combo:hover {
    color: #ffffff;
    border-color: transparent;
    background-image: linear-gradient(to bottom, @theme_selected_bg_color);
    box-shadow: none; }
.primary-toolbar combobox > .linked > button.combo:disabled, headerbar combobox > .linked > button.combo:disabled {

}

.primary-toolbar combobox > .linked > entry.combo:dir(ltr), headerbar combobox > .linked > entry.combo:dir(ltr) {
    border-right-style: none; 

}
.primary-toolbar combobox > .linked > entry.combo:dir(ltr):focus, headerbar combobox > .linked > entry.combo:dir(ltr):focus {
    box-shadow: none; 
}

.primary-toolbar combobox > .linked > entry.combo:dir(rtl), headerbar combobox > .linked > entry.combo:dir(rtl) {
    border-left-style: none; }
.primary-toolbar combobox > .linked > entry.combo:dir(rtl):focus, headerbar combobox > .linked > entry.combo:dir(rtl):focus {
    box-shadow: none; }

.primary-toolbar combobox > .linked > button.combo:dir(ltr), headerbar combobox > .linked > button.combo:dir(ltr), .primary-toolbar combobox > .linked > button.combo:dir(ltr):hover, headerbar combobox > .linked > button.combo:dir(ltr):hover, .primary-toolbar combobox > .linked > button.combo:dir(ltr):active, headerbar combobox > .linked > button.combo:dir(ltr):active, .primary-toolbar combobox > .linked > button.combo:dir(ltr):checked, headerbar combobox > .linked > button.combo:dir(ltr):checked, .primary-toolbar combobox > .linked > button.combo:dir(ltr):disabled, headerbar combobox > .linked > button.combo:dir(ltr):disabled {
    border-top-left-radius: 0;
    border-bottom-left-radius: 0; }

.primary-toolbar combobox > .linked > button.combo:dir(rtl), headerbar combobox > .linked > button.combo:dir(rtl), .primary-toolbar combobox > .linked > button.combo:dir(rtl):hover, headerbar combobox > .linked > button.combo:dir(rtl):hover, .primary-toolbar combobox > .linked > button.combo:dir(rtl):active, headerbar combobox > .linked > button.combo:dir(rtl):active, .primary-toolbar combobox > .linked > button.combo:dir(rtl):checked, headerbar combobox > .linked > button.combo:dir(rtl):checked, .primary-toolbar combobox > .linked > button.combo:dir(rtl):disabled, headerbar combobox > .linked > button.combo:dir(rtl):disabled {
    border-top-right-radius: 0;
    border-bottom-right-radius: 0; }

.primary-toolbar switch:backdrop, headerbar switch:backdrop {
    opacity: 0.75; }

.primary-toolbar progressbar trough, headerbar progressbar trough {
    background-color: rgba(21, 23, 28, 0.37); }

.primary-toolbar progressbar:backdrop, headerbar progressbar:backdrop {
    opacity: 0.75; }

.primary-toolbar scale:backdrop, headerbar scale:backdrop {
    opacity: 0.75; }

.primary-toolbar scale slider, headerbar scale slider {
   
}
.primary-toolbar scale slider:hover, headerbar scale slider:hover {
    
}
.primary-toolbar scale slider:active, headerbar scale slider:active {
    background-color: @theme_selected_bg_color;
    border-color: @theme_selected_bg_color; 
}
.primary-toolbar scale slider:disabled, headerbar scale slider:disabled {

}

.primary-toolbar scale trough, headerbar scale trough {

}
.primary-toolbar scale trough:disabled, headerbar scale trough:disabled {

}

.path-bar button.text-button, .path-bar button.image-button, .path-bar button {
    padding-left: 6px;
    padding-right: 6px; }

.path-bar button.text-button.image-button label {
    padding-left: 0;
    padding-right: 0; }

.path-bar button.text-button.image-button label:last-child, .path-bar button label:last-child {
    padding-right: 10px; }

.path-bar button.text-button.image-button label:first-child, .path-bar button label:first-child {
    padding-left: 10px; }

.path-bar button.slider-button, .path-bar button:not(.image-button):not(.text-button) {
    padding-left: 1px;
    padding-right: 1px; }

.path-bar button image {
    padding-left: 4px;
    padding-right: 4px; }

treeview.view {
    -GtkTreeView-grid-line-width: 1;
    -GtkTreeView-grid-line-pattern: '';
    -GtkTreeView-tree-line-width: 1;
    -GtkTreeView-tree-line-pattern: '';
    -GtkTreeView-expander-size: 16;
    border-left-color: rgba(211, 218, 227, 0.15);
    border-top-color: rgba(0, 0, 0, 0.1); }

treeview.view acceleditor > label {
    background-color: @theme_selected_bg_color; }
treeview.view:selected, treeview.view:selected:focus {
    border-radius: 0;
    border-left-color: #e6abae;
    border-top-color: rgba(211, 218, 227, 0.1); }
treeview.view:disabled {
    color: rgba(211, 218, 227, 0.45); }
treeview.view:disabled:selected {
    color: #e09a9e; }
treeview.view.separator {
    min-height: 2px;
    color: rgba(0, 0, 0, 0.1); }
treeview.view:drop(active) {
    border-style: solid none;
    border-width: 1px;
    border-color: #d099a0; }
treeview.view:drop(active).after {
    border-top-style: none; }
treeview.view:drop(active).before {
    border-bottom-style: none; }
treeview.view.expander {
    -gtk-icon-source: -gtk-icontheme("pan-end-symbolic");
    color: #8a909b; }
treeview.view.expander:dir(rtl) {
    -gtk-icon-source: -gtk-icontheme("pan-end-symbolic-rtl"); }
treeview.view.expander:hover {
    color: #D3DAE3; }
treeview.view.expander:selected {
    color: #f0cdce; }
treeview.view.expander:selected:hover {
    color: #ffffff; }
treeview.view.expander:checked {
    -gtk-icon-source: -gtk-icontheme("pan-down-symbolic"); }
treeview.view.progressbar, treeview.view.progressbar:focus {
    color: #ffffff;
    border-radius: 3px;
    background-image: linear-gradient(to bottom, @theme_selected_bg_color); }
treeview.view.progressbar:selected, treeview.view.progressbar:selected:focus, treeview.view.progressbar:focus:selected, treeview.view.progressbar:focus:selected:focus {
    color: @theme_selected_bg_color;
    box-shadow: none;
    background-image: linear-gradient(to bottom, #ffffff); }
treeview.view.trough, treeview.view.trough:selected, treeview.view.trough:selected:focus {
    color: #D3DAE3;
    background-image: linear-gradient(to bottom, #2b2e39);
    border-radius: 3px;
    border-width: 0; }


treeview.view header{
	padding: 1px 4px;
    background-image: url("darkelements/column-header.png");
	border: solid;
    border-image: url("darkelements/column-header-border.png") 1 1 2 1 / 1px 1px 2px 1px stretch stretch;
    border-width:1px 1px 2px 1px;
	background-size: 100% 100%;
	min-height: 21px;
}
treeview.view header button {
	padding: 1px 4px;
	border: solid;
    background-image: url("darkelements/column-header.png");
    border-image: url("darkelements/column-header-border.png") 1 1 2 1 / 1px 1px 2px 1px stretch stretch;
    border-width: 1px 1px 2px 1px;
	background-size: 100% 100%;
	min-height: 21px;
}
treeview.view header button:hover,
treeview.view header button:active,
treeview.view header button:hover
treeview.view header button:active:hover {
	padding: 1px 3px 1px 4px;
	border: solid;
    background-image: url("darkelements/button-hover.png");
    border-image: url("darkelements/column-header-hover-border.png") 1 2 2 1 / 1px 2px 2px 1px stretch;
    border-width: 1px 2px 2px 1px;
	background-size: 100% 100%;
}

treeview.view header button:disabled {

}
treeview.view header button:last-child {

}
treeview.view button.dnd, treeview.view button.dnd:selected, treeview.view button.dnd:hover, treeview.view button.dnd:active,
treeview.view header.button.dnd,
treeview.view header.button.dnd:selected,
treeview.view header.button.dnd:hover,
treeview.view header.button.dnd:active {

}

menubar,
.menubar {
    background-image: url("darkelements/menubar.png");
    border-style: solid;
    border-image:url("darkelements/menubar-border.png") 1 0 2 0 / 1px 0 2px 0 stretch;
    color: @theme_text_color;
    border-width: 1px 0 1px 0;
    border-color: transparent;
    padding:  2px 1px 1px 2px;
	background-size: 100% 100%;
    -GtkWidget-window-dragging: false;
}
menubar:backdrop,
.menubar:backdrop {


}
menubar > menuitem,
.menubar > menuitem {
    -GtkArrow-shadow-style:none;
	padding: 0 6px 0 6px;

}
menubar > menuitem:hover,
.menubar > menuitem:hover {
    background-image: url("darkelements/menubar-item.png");
	border: solid;	
    border-image: url("darkelements/menubar-item-border.png") 1 2 0 2 / 1px 2px 0 2px stretch stretch;
    border-width: 1px 2px 0 2px;
	background-size: 100% 100%;
	padding: 0 4px 0 4px;
margin-top: -2px;
}
menubar > menuitem:disabled,
.menubar > menuitem:disabled {
    color: rgba(207, 218, 231, 0.2);
    border-color: transparent; }

menu,
.menu {
    background-image: url("darkelements/menu-bg.png"); 
	border: solid;
    border-image: url("darkelements/menu-border.png") 5 5 5 23 / 5px 5px 5px 23px stretch stretch; 
    border-width: 5px 5px 5px 23px;
    color: @menu_fg_color;
	background-size: 100% 100%; 
	padding:1px;
}

menu separator,
.csd menu separator,
.menu separator,
.csd
.menu separator {
	-GtkWidget-wide-separators: true;
	-GtkWidget-separator-height: 2px;
	border:solid;
    border-image: url("darkelements/line-h.png") 0 0 2 0  stretch ;
	border-width:  0 0 2px 0;
}
menu .separator:not(label),
.csd menu .separator:not(label),
.menu .separator:not(label),
.csd
.menu .separator:not(label) { 

}

separator,
separator:hover,
separator:backdrop,
separator:hover:backdrop,
.separator,
.separator:hover,
.separator:backdrop,
.separator:hover:backdrop {
	-GtkWidget-wide-separators: true;
	-GtkWidget-separator-height: 2px;
	border:solid;
    border-image: url("darkelements/line-h.png") 0 0 2 0  stretch ;
	border-width:  0 0 2px 0;
   
}
separator.horizontal,
separator.horizontal:hover,
separator.horizontal:backdrop,
separator.horizontal:hover:backdrop,
.separator.horizontal,
.separator.horizontal:hover,
.separator.horizontal:backdrop,
.separator.horizontal:hover:backdrop {
	-GtkWidget-wide-separators: true;
	-GtkWidget-separator-width: 2px;
	-GtkWidget-separator-height: 2;
border:solid;
    background-image: url("darkelements/line-h.png");
	background-size: 100% 100%;
    border-image: url("darkelements/line-h.png") 2 0 0 0 / 2px 0 0 0 stretch ;
    border-width:2px;
    padding: 3px 2px;
    color: alpha(#ffffff, 0.1);
}

menu menuitem{
	color: @theme_text_color;
	border: solid alpha(black, 0);	
	border-width: 2px;
    padding: 0;
	background-color: transparent;
}

menuitem,
.menuitem{
	background-color: transparent;
	padding: 1px 4px 0 2px;
}
menu menuitem:hover,
.menu menuitem:hover {
    color: @theme_text_color;
	border: solid;	
	background-image: url("darkelements/menubar-item-active.png");
    border-image: url("darkelements/menubar-item-border-active.png") 2 2 2 2 / 2px 2px 2px 2px stretch stretch;
    border-width: 2px;
	background-size: 100% 100%;
    padding: 0;    
}
menu menuitem:disabled,
.menu menuitem:disabled {
    color: rgba(211, 218, 227, 0.45); 
}

menuitem:prelight,
.menuitem:prelight { 
    border: solid;
    background-image: url("darkelements/menubar-item-active.png");
    border-image: url("darkelements/menubar-item-border-active.png") 2 2 2 2 / 2px 2px 2px 2px stretch stretch;
    border-width: 2px;
    background-size: 100% 100%;
    padding: 1px 4px 0 2px;
    border-color: transparent;
    background-color: transparent;
}





menu menuitem arrow,
.menu menuitem arrow {
    min-height: 16px;
    min-width: 16px; }
menu menuitem arrow:dir(ltr),
.menu menuitem arrow:dir(ltr) {
    -gtk-icon-source: -gtk-icontheme("pan-end-symbolic");
    margin-left: 10px; }
menu menuitem arrow:dir(rtl),
.menu menuitem arrow:dir(rtl) {
    -gtk-icon-source: -gtk-icontheme("pan-end-symbolic-rtl");
    margin-right: 10px; }
menuitem accelerator {
    color: alpha(currentColor,0.55); }
menuitem check, menuitem radio {
    min-height: 16px;
    min-width: 16px; }
menuitem check:dir(ltr), menuitem radio:dir(ltr) {
    margin-right: 6px;
    margin-left: 2px; }
menuitem check:dir(rtl), menuitem radio:dir(rtl) {
    margin-left: 6px;
    margin-right: 2px; }
menu > arrow,
.menu > arrow {
    border-color: transparent;
    background-color: transparent;
    background-image: none;
    min-width: 16px;
    min-height: 16px;
    padding: 4px;
    background-color: #383C4A;
    border-radius: 0; 
	-gtk-icon-source: -gtk-icontheme("pan-right-symbolic")
}
menu > arrow.top,
.menu > arrow.top {
    margin-top: -6px;
    border-bottom: 1px solid #4f5461;
    -gtk-icon-source: -gtk-icontheme("pan-up-symbolic"); }
menu > arrow.bottom,
.menu > arrow.bottom {
    margin-bottom: -6px;
    border-top: 1px solid #4f5461;
    -gtk-icon-source: -gtk-icontheme("pan-down-symbolic"); }
menu > arrow:hover,
.menu > arrow:hover {
    background-color: #4f5461; }
menu > arrow:disabled,
.menu > arrow:disabled {
    color: transparent;
    background-color: transparent;
    border-color: transparent; }

popover,
popover.background {
    padding: 2px;
    border-radius: 3px;
    background-clip: border-box;
    background-color: #383C4A;
    box-shadow: 0 2px 6px 1px rgba(0, 0, 0, 0.35); }
.csd popover, popover, .csd
popover.background,
popover.background {
    border: 1px solid #20222a; }
popover separator,
popover.background separator {
    background-color: #383C4A; }
popover > list,
popover > .view,
popover > iconview,
popover > toolbar,
popover > .inline-toolbar,
popover.background > list,
popover.background > .view,
popover.background > iconview,
popover.background > toolbar,
popover.background > .inline-toolbar {
    border-style: none;
    background-color: transparent; }

cursor-handle {
    background-color: transparent;
    background-image: none;
    box-shadow: none;
    border-style: none; }
cursor-handle.top {
    -gtk-icon-source: -gtk-icontheme("selection-start-symbolic"); }
cursor-handle.bottom {
    -gtk-icon-source: -gtk-icontheme("selection-end-symbolic"); }

notebook {
    
}
notebook.frame {
    }
notebook.frame > header {
    padding-top: 5px; }
notebook.frame > header.top {
    margin-bottom: 0; }
notebook.frame > header.bottom {
    margin-top: 0; }
notebook.frame > header.left {
    margin-right: 0; }
notebook.frame > header.right {
    margin-left: 0; }
notebook.frame > header.top, notebook.frame > header.bottom {
    padding-left: 0;
    padding-right: 0; }
notebook.frame > header.left, notebook.frame > header.right {
    padding-top: 0;
    padding-bottom: 0; }
notebook > stack:not(:only-child) {
    background-color: @theme_bg_color; }
notebook > header {
    }
/*
notebook > header.top {
    box-shadow: inset 0 -1px #2b2e39; 
}
notebook > header.bottom {
    box-shadow: inset 0 1px #2b2e39; }
notebook > header.right {
    box-shadow: inset 1px 0 #2b2e39; }
notebook > header.left {
    box-shadow: inset -1px 0 #2b2e39; }

notebook > header.top {
    margin-left: -2px;  }
*/

notebook > header.top > tabs > tab{ /* first */
	padding: 2px 5px 0 5px;
	border: solid;
    background-image: url("darkelements/tab-top.png");
    border-image: url("darkelements/tab-top-border.png") 2 2 0 2 / 2px 2px 0 2px stretch stretch;
    border-width:2px 1px 0 2px;
  	background-size: 100% 100%;
}
notebook > header.top > tabs > tab+tab { /* nth-child(n+1) */
	
	padding: 2px 5px 0 5px;
	border: solid;
    background-image: url("darkelements/tab-top.png");
    border-image: url("darkelements/tab-top-border.png") 2 2 0 0 / 2px 2px 0 0 stretch stretch;
    border-width:2px 1px 0 0;
  	background-size: 100% 100%;
}
notebook > header.top > tabs > tab:checked {
	padding: 3px 7px 1px 7px;
	border: solid;
	background-size: 100% 100%;
	background-image: -gtk-gradient (linear,
                                    0 0, 0 1,
                                    color-stop(0, #0D479F),
                                    color-stop(0.5, #000000),
									color-stop(1, #252525)
						);
    border-image: url("darkelements/tab-top-active-border.png") 2 2 0 2 / 2px 2px 0 2px stretch stretch;
    border-width: 2px 2px 0 2px;
}

notebook > header.top > tabs > tab button {
	padding: 0;
	background-image: none;
	border-image: none;
	border-width:2px;
	background-color: transparent;
	border-color: transparent;
}

notebook > header.top > tabs > tab button:hover,
notebook > header.top > tabs > tab button:active,
notebook > header.top > tabs > tab button:selected,
notebook > header.top > tabs > tab button:checked{
border: solid;
    background-image: url("darkelements/button-hover.png");
    border-image: url("darkelements/button-hover-border.png") 2 2 2 2 / 2px 2px 2px 2px stretch stretch;
    border-width:2px;
	background-size: 100% 100%;
}


notebook > header.bottom {
    padding-top: 0; }
notebook > header.bottom > tabs > tab {
    padding: 2px 10px;
    min-width: 20px;
    min-height: 20px;
    outline-offset: -4px;
    border: 1px solid transparent;
    border-top: none;
    border-radius: 0 0 1px 1px; }
notebook > header.bottom > tabs > tab + tab {
    margin-left: -1px; }
notebook > header.right {
    padding-left: 0; }
notebook > header.right > tabs > tab {
    padding: 2px 10px;
    min-width: 20px;
    min-height: 20px;
    outline-offset: -4px;
    border: 1px solid transparent;
    border-left: none;
    border-radius: 0 1px 1px 0; }
notebook > header.right > tabs > tab + tab {
    margin-top: -1px; }
notebook > header.left {
    padding-right: 0; }
notebook > header.left > tabs > tab {
    padding: 2px 10px;
    min-width: 20px;
    min-height: 20px;
    outline-offset: -4px;
    border: 1px solid transparent;
    border-right: none;
    border-radius: 1px 0 0 1px; }
notebook > header.left > tabs > tab + tab {
    margin-top: -1px; }
notebook > header.top > tabs > arrow.up, notebook > header.bottom > tabs > arrow.up {
    -gtk-icon-source: -gtk-icontheme("pan-end-symbolic"); }
notebook > header.top > tabs > arrow.up:last-child, notebook > header.bottom > tabs > arrow.up:last-child {
    margin-left: 2px; }
notebook > header.top > tabs > arrow.down, notebook > header.bottom > tabs > arrow.down {
    -gtk-icon-source: -gtk-icontheme("pan-start-symbolic"); }
notebook > header.top > tabs > arrow.down:first-child, notebook > header.bottom > tabs > arrow.down:first-child {
    margin-right: 2px; }
notebook > header.left > tabs > arrow.up, notebook > header.right > tabs > arrow.up {
    -gtk-icon-source: -gtk-icontheme("pan-down-symbolic"); }
notebook > header.left > tabs > arrow.up:last-child, notebook > header.right > tabs > arrow.up:last-child {
    margin-top: 2px; }
notebook > header.left > tabs > arrow.down, notebook > header.right > tabs > arrow.down {
    -gtk-icon-source: -gtk-icontheme("pan-up-symbolic"); }
notebook > header.left > tabs > arrow.down:first-child, notebook > header.right > tabs > arrow.down:first-child {
    margin-bottom: 2px; }
notebook > header > tabs > arrow {
    color: rgba(211, 218, 227, 0.45); }
notebook > header > tabs > arrow:hover {
    color: rgba(211, 218, 227, 0.725); }
notebook > header > tabs > arrow:active {
    color: #D3DAE3; }
notebook > header > tabs > arrow:disabled {
    color: rgba(211, 218, 227, 0.15); }
notebook > header.top > tabs > tab:hover:not(:checked) {
    box-shadow: inset 0 -1px #2b2e39; }
notebook > header.bottom > tabs > tab:hover:not(:checked) {
    box-shadow: inset 0 1px #2b2e39; }
notebook > header.left > tabs > tab:hover:not(:checked) {
    box-shadow: inset -1px 0 #2b2e39; }
notebook > header.right > tabs > tab:hover:not(:checked) {
    box-shadow: inset 1px 0 #2b2e39; }
notebook > header > tabs > tab {
    color: rgba(211, 218, 227, 0.45);
    background-color: rgba(64, 69, 82, 0); }
notebook > header > tabs > tab:hover:not(:checked) {
    color: rgba(211, 218, 227, 0.725);
    background-color: rgba(64, 69, 82, 0.5);
    border-color: #ff0000; }
notebook > header > tabs > tab:checked {
    color: #D3DAE3;
    background-color: @theme_bg_color;
    border-color: #ff0000; }
notebook > header > tabs > tab button.flat, notebook > header > tabs > tab button.sidebar-button {
    min-height: 22px;
    min-width: 16px;
    padding: 0;
    color: #ff0000; }
notebook > header > tabs > tab button.flat:hover, notebook > header > tabs > tab button.sidebar-button:hover {
    color: #ff0000; }
notebook > header > tabs > tab button.flat:active, notebook > header > tabs > tab button.sidebar-button:active, notebook > header > tabs > tab button.flat:active:hover, notebook > header > tabs > tab button.sidebar-button:active:hover {
    color: @theme_selected_bg_color; }


scrollbar {
 -GtkScrollbar-has-backward-stepper: true;
 -GtkScrollbar-has-forward-stepper: true; 

    background-image: none;
    border-style: solid;
    -GtkRange-trough-border: 0;
    
    -GtkRange-slider-width: 16px;
    -GtkRange-stepper-size: 16px;

} 


scrollbar button {
border: 1px solid;
    background-image: url("darkelements/scrollbars/stepper.png") ;
    /*background-color: @theme_base_color;*/
    border-color: #000000;
	background-size: 100% 100%;
	color: #ffffff;
}


scrollbar.vertical {
     border-image: url("darkelements/scrollbars/trough-scrollbar-vert.png") 0 16 0 0 / 0 16px 0 0 stretch stretch;

    padding:0;
    background-color:#000000; 
}
scrollbar.vertical button.down {
    border: 1px solid;
    background-image: url("darkelements/scrollbars/stepper-down.png") 0 16 0 0 / 0 16px 0 0;
    /*background-color: @theme_base_color;*/
    border-color: #000000;
	background-size: 100% 100%;
	color: #ffffff; 
}
scrollbar.vertical button {
 	min-height: 14px;
	max-height: 14px;
}
scrollbar.horizontal button.up {	
border: 1px solid;
 background-image: url("darkelements/scrollbars/stepper-left.png"); 
border-color: #000000;
	background-size: 100% 100%;
	color: transparent;
}
scrollbar.horizontal button.up:hover {	
border: 1px solid;
 background-image: url("darkelements/scrollbars/stepper-left-prelight.png"); 
border-color: #000000;
	background-size: 100% 100%;
	color: transparent;
}
scrollbar.horizontal button.down {	
border: 1px solid;
 background-image: url("darkelements/scrollbars/stepper-right.png"); 
border-color: #000000;
	background-size: 100% 100%;
	color: transparent;
} 
scrollbar.horizontal button.down:hover {	
border: 1px solid;
 background-image: url("darkelements/scrollbars/stepper-right-prelight.png"); 
border-color: #000000;
	background-size: 100% 100%;
	color: transparent;
}



scrollbar.vertical button.up {	
 	border: 1px solid;
    background-image: url("darkelements/scrollbars/stepper-up.png") ;
    /*background-color: @theme_base_color;*/
    border-color: #000000;
	background-size: 100% 100%;
	color: transparent;

}	


scrollbar.vertical button.up:hover {
	border: 1px solid;
    background-image: url("darkelements/scrollbars/stepper-up-prelight.png") ;
    /*background-color: @theme_base_color;*/
    border-color: #000000;
	background-size: 100% 100%;
	color: transparent;
}	
scrollbar.vertical button.down {
 	border: 1px solid;
    background-image: url("darkelements/scrollbars/stepper-down.png") ;
    /*background-color: @theme_base_color;*/
    border-color: #000000;
	background-size: 100% 100%;
	color: transparent;  
}
scrollbar.vertical button.down:hover {
	border: 1px solid;
    background-image: url("darkelements/scrollbars/stepper-down-prelight.png") ;
    /*background-color: @theme_base_color;*/
    border-color: #000000;
	background-size: 100% 100%;
	color: transparent;
}

scrollbar slider {
    min-width: 16px;
	max-width: 16px;
    border-image: url("darkelements/scrollbars/slider-vert.png") 2 8 2 8 / 2px 8px 2px 8px round stretch;
    border-width: 2px 8px; 
}
scrollbar slider:hover,
scrollbar slider:hover:active{
    border-image: url("darkelements/scrollbars/slider-vert-active.png") 2 8 2 8 / 2px 8px 2px 8px round stretch;
    border-width: 2px 8px;
}

scrollbar slider:disabled {
    background-color: transparent; }
scrollbar.fine-tune slider {
    min-width: 4px;
    min-height: 4px; }
scrollbar.fine-tune.horizontal slider {
    border-width: 5px 4px; }
scrollbar.fine-tune.vertical slider {
    border-width: 4px 5px; }
scrollbar.overlay-indicator:not(.dragging):not(.hovering){
}
scrollbar.overlay-indicator:not(.dragging):not(.hovering) slider {
    border-image: url("darkelements/scrollbars/slider-vert.png") 2 8 2 8 / 2px 8px 2px 8px round stretch;
    border-width: 2px 8px;    
}
scrollbar.overlay-indicator:not(.dragging):not(.hovering).horizontal slider {
    margin: 0 2px;
    min-width: 40px; }
scrollbar.overlay-indicator:not(.dragging):not(.hovering).vertical slider {

}
scrollbar.overlay-indicator.dragging, scrollbar.overlay-indicator.hovering {

}
scrollbar.horizontal slider {
    min-width: 40px; }
scrollbar.vertical slider {
    min-height: 40px; }
/* the small square between scrollbars!!!
     no borders with background-image */
scrolledwindow junction {
    background-image: linear-gradient(to bottom,
                                      shade(@theme_bg_color, 1.00),
                                      shade(@theme_bg_color, 1.00));
    border-image: linear-gradient(to bottom,
                                      shade(@theme_bg_color, 1.00),
                                      shade(@theme_bg_color, 1.00));
    background-color: transparent;
    border-style: none;
    border-width: 0;
    box-shadow: none;
}

switch {
    font: 1;
    min-width: 74px;
    min-height: 24px;
    background-size: 74px 24px;
    background-repeat: no-repeat;
    background-position: center center; }
switch slider {
    min-width: 1px;
    min-height: 1px; }
switch, switch slider {
    outline-color: transparent;
    color: transparent;
    border: none;
    box-shadow: none; }

switch {
    background-image: url("darkelements/switch/switcher-off.png");
    width: 74px;
    height: 24px;
}

menuitem:hover switch,
row:selected switch,
infobar switch {
    background-image: url("darkelements/switch/switcher-off.png");
    width: 74px;
    height: 24px;
}

headerbar switch,
.primary-toolbar switch {
    background-image: url("darkelements/switch/switcher-off.png");
    width: 74px;
    height: 24px;
}

switch:checked {
    background-image: url("darkelements/switch/switcher-on.png");
    width: 74px;
    height: 24px;
}

menuitem:hover switch:checked,
row:selected switch:checked,
infobar switch:checked {
    background-image: url("darkelements/switch/switcher-on.png");
    width: 74px;
    height: 24px;    
}

headerbar switch:checked,
.primary-toolbar switch:checked {
    background-image: url("darkelements/switch/switcher-on.png");
    width: 74px;
    height: 24px;
}

switch:disabled {
    background-image: -gtk-scaled(url("assets/switch-insensitive-dark.png"), url("assets/switch-insensitive-dark@2.png")); }

menuitem:hover switch:disabled,
row:selected switch:disabled,
infobar switch:disabled {
    background-image: -gtk-scaled(url("assets/switch-insensitive-selected.png"), url("assets/switch-insensitive-selected@2.png")); }

headerbar switch:disabled,
.primary-toolbar switch:disabled {
    background-image: -gtk-scaled(url("assets/switch-insensitive-header-dark.png"), url("assets/switch-insensitive-header-dark@2.png")); }

switch:checked:disabled {
    background-image: -gtk-scaled(url("assets/switch-active-insensitive-dark.png"), url("assets/switch-active-insensitive-dark@2.png")); }

menuitem:hover switch:checked:disabled,
row:selected switch:checked:disabled,
infobar switch:checked:disabled {
    background-image: -gtk-scaled(url("assets/switch-active-insensitive-selected.png"), url("assets/switch-active-insensitive-selected@2.png")); }

headerbar switch:checked:disabled,
.primary-toolbar switch:checked:disabled {
    background-image: -gtk-scaled(url("assets/switch-active-insensitive-header-dark.png"), url("assets/switch-active-insensitive-header-dark@2.png")); }

.check,
check,
treeview.check{
	-gtk-icon-source: -gtk-scaled(url("darkelements/check-radio/check1.png"), url("darkelements/check-radio/check1.png"));
	padding-right: 5px;
	margin-right: 5px;  
}
.osd check, filechooser actionbar check {
	-gtk-icon-source: -gtk-scaled(url("darkelements/check-radio/check1.png"), url("darkelements/check-radio/check1.png"));
	padding-right: 5px;
	margin-right: 5px;    
}

check:hover,
heck:selected,
menuitem check:hover,
.view check:selected, iconview check:selected,
treeview.check:selected,
row:selected check,
infobar check {
-gtk-icon-source: -gtk-scaled(url("darkelements/check-radio/check3.png"), url("darkelements/check-radio/check3.png"));    
}

.check:disabled,
check:disabled,
treeview.check:disabled {
-gtk-icon-source: -gtk-scaled(url("darkelements/check-radio/check5.png"), url("darkelements/check-radio/check5.png"));    
}

.osd check:disabled, filechooser actionbar check:disabled {
    -gtk-icon-source: -gtk-scaled(url("darkelements/check-radio/check5.png"), url("darkelements/check-radio/check5.png"));
}

menuitem check:disabled:hover,
.view check:disabled:selected, iconview check:disabled:selected,
treeview.check:disabled:selected,
row:selected check:disabled,
infobar check:disabled {
    -gtk-icon-source: -gtk-scaled(url("darkelements/check-radio/check5.png"), url("darkelements/check-radio/check5.png"));
}
.check:indeterminate,
check:indeterminate,
treeview.check:indeterminate {
    -gtk-icon-source: -gtk-scaled(url("darkelements/check-radio/check5.png"), url("darkelements/check-radio/check5.png"));
}
.osd check:indeterminate, filechooser actionbar check:indeterminate {
    -gtk-icon-source: -gtk-scaled(url("darkelements/check-radio/check5.png"), url("darkelements/check-radio/check5.png"));
}
menuitem check:indeterminate:hover,
.view check:indeterminate:selected, iconview check:indeterminate:selected,
treeview.check:indeterminate:selected,
row:selected check:indeterminate,
infobar check:indeterminate {
    -gtk-icon-source: -gtk-scaled(url("darkelements/check-radio/check5.png"), url("darkelements/check-radio/check5.png"));
}
.check:indeterminate:disabled,
check:indeterminate:disabled,
treeview.check:indeterminate:disabled {
    -gtk-icon-source: -gtk-scaled(url("darkelements/check-radio/check5.png"), url("darkelements/check-radio/check5.png"));
}
.osd check:indeterminate:disabled, filechooser actionbar check:indeterminate:disabled {
    -gtk-icon-source: -gtk-scaled(url("darkelements/check-radio/check5.png"), url("darkelements/check-radio/check5.png"));
}
menuitem check:indeterminate:disabled:hover,
.view check:indeterminate:disabled:selected, iconview check:indeterminate:disabled:selected,
treeview.check:indeterminate:disabled:selected,
row:selected check:indeterminate:disabled,
infobar check:indeterminate:disabled {
    -gtk-icon-source: -gtk-scaled(url("darkelements/check-radio/check5.png"), url("darkelements/check-radio/check5.png"));
}

.check:checked,
check:checked,
treeview.check:checked {
    -gtk-icon-source: -gtk-scaled(url("darkelements/check-radio/check2.png"), url("darkelements/check-radio/check2.png"));	
}
check:checked:prelight,
.check:checked:prelight,
treeview.check:checked:prelight{
	-gtk-icon-source: -gtk-scaled(url("darkelements/check-radio/check4.png"), url("darkelements/check-radio/check4.png"));	
}

.osd check:checked, filechooser actionbar check:checked {
    -gtk-icon-source: -gtk-scaled(url("darkelements/check-radio/check2.png"), url("darkelements/check-radio/check2.png"));	
}
menuitem check:checked:hover,
.view check:checked:selected, iconview check:checked:selected,
treeview.check:checked:selected,
row:selected check:checked,
infobar check:checked {
    -gtk-icon-source: -gtk-scaled(url("darkelements/check-radio/check3.png"), url("darkelements/check-radio/check3.png"));	
}
.check:checked:disabled,
check:checked:disabled,
treeview.check:checked:disabled {
-gtk-icon-source: -gtk-scaled(url("darkelements/check-radio/check6.png"), url("darkelements/check-radio/check6.png"));
}
.osd check:checked:disabled, filechooser actionbar check:checked:disabled {
-gtk-icon-source: -gtk-scaled(url("darkelements/check-radio/check6.png"), url("darkelements/check-radio/check6.png"));
}
menuitem check:checked:disabled:hover,
.view check:checked:disabled:selected, iconview check:checked:disabled:selected,
treeview.check:checked:disabled:selected,
row:selected check:checked:disabled,
infobar check:checked:disabled {
    -gtk-icon-source: -gtk-scaled(url("darkelements/check-radio/check6.png"), url("darkelements/check-radio/check6.png"));
}

.radio,
radio,
treeview.radio {
	-gtk-icon-source: -gtk-scaled(url("darkelements/check-radio/option1.png"), url("darkelements/check-radio/option1.png"));
}
.osd radio, filechooser actionbar radio {
	-gtk-icon-source: -gtk-scaled(url("darkelements/check-radio/option1.png"), url("darkelements/check-radio/option1.png"));
}
menuitem radio:hover,
.view radio:selected, iconview radio:selected,
treeview.radio:selected,
row:selected radio,
infobar radio {
	-gtk-icon-source: -gtk-scaled(url("darkelements/check-radio/option3.png"), url("darkelements/check-radio/option3.png"));
	
}
.radio:disabled,
radio:disabled,
treeview.radio:disabled {
	-gtk-icon-source: -gtk-scaled(url("darkelements/check-radio/option5.png"), url("darkelements/check-radio/option5.png"));
	
}
.osd radio:disabled, filechooser actionbar radio:disabled {
 	-gtk-icon-source: -gtk-scaled(url("darkelements/check-radio/option5.png"), url("darkelements/check-radio/option5.png"));
	
}
menuitem radio:disabled:hover,
.view radio:disabled:selected, iconview radio:disabled:selected,
treeview.radio:disabled:selected,
row:selected radio:disabled,
infobar radio:disabled {
 	-gtk-icon-source: -gtk-scaled(url("darkelements/check-radio/option5.png"), url("darkelements/check-radio/option5.png"));
	
}
.radio:indeterminate,
radio:indeterminate,
treeview.radio:indeterminate {
	-gtk-icon-source: -gtk-scaled(url("darkelements/check-radio/option1.png"), url("darkelements/check-radio/option1.png"));
	
}
.osd radio:indeterminate, filechooser actionbar radio:indeterminate {
	-gtk-icon-source: -gtk-scaled(url("darkelements/check-radio/option1.png"), url("darkelements/check-radio/option1.png"));
	
}
menuitem radio:indeterminate:hover,
.view radio:indeterminate:selected, iconview radio:indeterminate:selected,
treeview.radio:indeterminate:selected,
row:selected radio:indeterminate,
infobar radio:indeterminate {
	-gtk-icon-source: -gtk-scaled(url("darkelements/check-radio/option3.png"), url("darkelements/check-radio/option3.png"));
	
}
.radio:indeterminate:disabled,
radio:indeterminate:disabled,
treeview.radio:indeterminate:disabled {
	-gtk-icon-source: -gtk-scaled(url("darkelements/check-radio/option5.png"), url("darkelements/check-radio/option5.png"));
	
}
.osd radio:indeterminate:disabled, filechooser actionbar radio:indeterminate:disabled {
	-gtk-icon-source: -gtk-scaled(url("darkelements/check-radio/option5.png"), url("darkelements/check-radio/option5.png"));
	
}
menuitem radio:indeterminate:disabled:hover,
.view radio:indeterminate:disabled:selected, iconview radio:indeterminate:disabled:selected,
treeview.radio:indeterminate:disabled:selected,
row:selected radio:indeterminate:disabled,
infobar radio:indeterminate:disabled {
 	-gtk-icon-source: -gtk-scaled(url("darkelements/check-radio/option5.png"), url("darkelements/check-radio/option5.png"));
	
}
.radio:checked,
radio:checked,
treeview.radio:checked {
	-gtk-icon-source: -gtk-scaled(url("darkelements/check-radio/option2.png"), url("darkelements/check-radio/option.png"));
	
}
.osd radio:checked, filechooser actionbar radio:checked {
	-gtk-icon-source: -gtk-scaled(url("darkelements/check-radio/option2.png"), url("darkelements/check-radio/option.png"));
	
}
menuitem radio:checked:hover,
.view radio:checked:selected, iconview radio:checked:selected,
treeview.radio:checked:selected,
row:selected radio:checked,
infobar radio:checked {
	-gtk-icon-source: -gtk-scaled(url("darkelements/check-radio/option4.png"), url("darkelements/check-radio/option4.png"));
	
}

.radio:checked:disabled,
radio:checked:disabled,
treeview.radio:checked:disabled {
	-gtk-icon-source: -gtk-scaled(url("darkelements/check-radio/option6.png"), url("darkelements/check-radio/option6.png"));
}
.osd radio:checked:disabled, filechooser actionbar radio:checked:disabled {
	-gtk-icon-source: -gtk-scaled(url("darkelements/check-radio/option6.png"), url("darkelements/check-radio/option6.png"));
}
menuitem radio:checked:disabled:hover,
.view radio:checked:disabled:selected, iconview radio:checked:disabled:selected,
treeview.radio:checked:disabled:selected,
row:selected radio:checked:disabled,
infobar radio:checked:disabled {
	-gtk-icon-source: -gtk-scaled(url("darkelements/check-radio/option6.png"), url("darkelements/check-radio/option6.png"));
}
.view.content-view.check:not(list), iconview.content-view.check:not(list) {
    	-gtk-icon-source: -gtk-scaled(url("darkelements/check-radio/check6.png"), url("darkelements/check-radio/check6.png"));
    background-color: transparent; }

.view.content-view.check:checked:not(list), iconview.content-view.check:checked:not(list) {
    	-gtk-icon-source: -gtk-scaled(url("darkelements/check-radio/check4.png"), url("darkelements/check-radio/check4.png"));
	background-color: transparent; 
}

checkbutton.text-button, radiobutton.text-button {
    padding: 2px 0;
    outline-offset: 0; }

checkbutton label:not(:only-child):first-child, radiobutton label:not(:only-child):first-child {
    margin-left: 4px; }

checkbutton label:not(:only-child):last-child, radiobutton label:not(:only-child):last-child {
    margin-right: 4px; }

check,
radio {
    min-width: 16px;
    min-height: 16px;
    margin: 0 2px; }
check:only-child,
menu menuitem check,
radio:only-child,
menu menuitem
radio {
    margin: 0; }

scale {
    min-height: 15px;
    min-width: 15px;
    padding: 3px; }
scale.horizontal trough {
    padding: 0 4px; }
scale.horizontal highlight, scale.horizontal fill {
    margin: 0 -4px; }
scale.vertical trough {
    padding: 4px 0; }
scale.vertical highlight, scale.vertical fill {
    margin: -4px 0; }
scale slider {
    min-height: 15px;
    min-width: 15px;
    margin: -6px; }
scale.fine-tune slider {
    margin: -4px; }
scale.fine-tune fill,
scale.fine-tune highlight,
scale.fine-tune trough {
    border-radius: 5px;
    -gtk-outline-radius: 7px; }
scale trough {
    outline-offset: 2px;
    -gtk-outline-radius: 4.5px;
    border-radius: 2.5px;
    background-color: #2d303b; }
scale trough:disabled {
    background-color: rgba(45, 48, 59, 0.55); }
.osd scale trough {
    background-color: rgba(69, 74, 89, 0.95); }
.osd scale trough highlight {
    background-color: @theme_selected_bg_color; }
menuitem:hover scale trough,
row:selected scale trough,
infobar scale trough {
    background-color: rgba(0, 0, 0, 0.2); }
menuitem:hover scale trough highlight,
row:selected scale trough highlight,
infobar scale trough highlight {
    background-color: #ffffff; }
menuitem:hover scale trough highlight:disabled,
row:selected scale trough highlight:disabled,
infobar scale trough highlight:disabled {
    background-color: #e8b3b6; }
menuitem:hover scale trough:disabled,
row:selected scale trough:disabled,
infobar scale trough:disabled {
    background-color: rgba(0, 0, 0, 0.1); }
scale highlight {
    border-radius: 2.5px;
    background-color: @theme_selected_bg_color; }
scale highlight:disabled {
    background-color: rgba(204, 87, 93, 0.55); }
scale fill {
    border-radius: 2.5px;
    background-color: rgba(204, 87, 93, 0.5); }
scale fill:disabled {
    background-color: transparent; }
scale slider {
    background-color: #444a58;
    border: 1px solid #262933;
    border-radius: 100%;
    transition: all 200ms cubic-bezier(0.25, 0.46, 0.45, 0.94);
    transition-property: background, border; }
scale slider:hover {
    background-color: #505666; }
scale slider:active {
    background-clip: border-box;
    background-color: @theme_selected_bg_color;
    border-color: @theme_selected_bg_color; }
scale slider:disabled {
    background-color: #3c414e;
    border-color: rgba(38, 41, 51, 0.8); }
menuitem:hover scale slider,
row:selected scale slider,
infobar scale slider {
    background-clip: border-box;
    background-color: #ffffff;
    border-color: #ffffff; }
menuitem:hover scale slider:hover,
row:selected scale slider:hover,
infobar scale slider:hover {
    background-color: #f7e6e7;
    border-color: #f7e6e7; }
menuitem:hover scale slider:active,
row:selected scale slider:active,
infobar scale slider:active {
    background-color: #e6abae;
    border-color: #e6abae; }
menuitem:hover scale slider:disabled,
row:selected scale slider:disabled,
infobar scale slider:disabled {
    background-color: #e8b3b6;
    border-color: #e8b3b6; }
.osd scale slider {
    background-clip: border-box;
    background-color: @theme_selected_bg_color;
    border-color: @theme_selected_bg_color; }
.osd scale slider:hover {
    background-color: #d87e83;
    border-color: #d87e83; }
.osd scale slider:active {
    background-color: #b8383e;
    border-color: #b8383e; }
scale value {
    color: alpha(currentColor,0.4); }
scale marks {
    color: alpha(currentColor,0.4); }
scale marks.top {
    margin-bottom: 1px;
    margin-top: -4px; }
scale marks.bottom {
    margin-top: 1px;
    margin-bottom: -4px; }
scale marks.top {
    margin-right: 1px;
    margin-left: -4px; }
scale marks.bottom {
    margin-left: 1px;
    margin-right: -4px; }
scale.fine-tune marks.top {
    margin-bottom: 0px;
    margin-top: -2px; }
scale.fine-tune marks.bottom {
    margin-top: 0px;
    margin-bottom: -2px; }
scale.fine-tune marks.top {
    margin-right: 0px;
    margin-left: -2px; }
scale.fine-tune marks.bottom {
    margin-left: 0px;
    margin-right: -2px; }
scale.horizontal indicator {
    min-height: 3px;
    min-width: 1px; }
scale.horizontal.fine-tune indicator {
    min-height: 2px; }
scale.vertical indicator {
    min-height: 1px;
    min-width: 3px; }
scale.vertical.fine-tune indicator {
    min-width: 2px; }

progressbar {
    padding: 0;
    font-size: smaller;
    color: rgba(211, 218, 227, 0.7); }
progressbar.osd {
    min-width: 3px;
    min-height: 3px;
    background-color: transparent; }
progressbar.osd trough {
    border-style: none;
    background-color: transparent;
    box-shadow: none; }
progressbar progress {
    background-color: @theme_selected_bg_color;
    border: none;
    border-radius: 3px;
    box-shadow: none; }
row:selected progressbar progress,
infobar progressbar progress {
    background-color: #ffffff; }
progressbar trough {
    border: none;
    border-radius: 3px;
    background-color: #2d303b; }
row:selected progressbar trough,
infobar progressbar trough {
    background-color: rgba(0, 0, 0, 0.2); }

levelbar block {
    min-width: 32px;
    min-height: 1px; }

levelbar.vertical block {
    min-width: 1px;
    min-height: 32px; }

levelbar trough {
    border: none;
    padding: 3px;
    border-radius: 3px;
    background-color: #2d303b; }

levelbar.horizontal.discrete block {
    margin: 0 1px; }

levelbar.vertical.discrete block {
    margin: 1px 0; }

levelbar block:not(.empty) {
    border: 1px solid @theme_selected_bg_color;
    background-color: @theme_selected_bg_color;
    border-radius: 2px; }

levelbar block.low {
    border-color: #F27835;
    background-color: #F27835; }

levelbar block.high {
    border-color: @theme_selected_bg_color;
    background-color: @theme_selected_bg_color; }

levelbar block.full {
    border-color: #73d216;
    background-color: #73d216; }

levelbar block.empty {
    background-color: @theme_bg_color;
    border-color: @theme_bg_color; }

printdialog paper {
    border: 1px solid #2b2e39;
    background: @theme_bg_color;
    padding: 0; }

printdialog .dialog-action-box {
    margin: 12px; }

frame > border,
.frame {
    margin: 0;
    padding: 0;
    border-radius: 0;
    border: 1px solid #2b2e39; }
frame > border.flat,
.frame.flat {
    border-style: none; }

scrolledwindow viewport.frame {
    border-style: none; }

scrolledwindow overshoot.top {
    background-image: -gtk-gradient(radial, center top, 0, center top, 0.6, from(rgba(204, 87, 93, 0.2)), to(rgba(204, 87, 93, 0)));
    background-size: 100% 60%;
    background-repeat: no-repeat;
    background-position: center top;
    background-color: transparent;
    border: none;
    box-shadow: none; }

scrolledwindow overshoot.bottom {
    background-image: -gtk-gradient(radial, center bottom, 0, center bottom, 0.6, from(rgba(204, 87, 93, 0.2)), to(rgba(204, 87, 93, 0)));
    background-size: 100% 60%;
    background-repeat: no-repeat;
    background-position: center bottom;
    background-color: transparent;
    border: none;
    box-shadow: none; }

scrolledwindow overshoot.left {
    background-image: -gtk-gradient(radial, left center, 0, left center, 0.6, from(rgba(204, 87, 93, 0.2)), to(rgba(204, 87, 93, 0)));
    background-size: 60% 100%;
    background-repeat: no-repeat;
    background-position: left center;
    background-color: transparent;
    border: none;
    box-shadow: none; }

scrolledwindow overshoot.right {
    background-image: -gtk-gradient(radial, right center, 0, right center, 0.6, from(rgba(204, 87, 93, 0.2)), to(rgba(204, 87, 93, 0)));
    background-size: 60% 100%;
    background-repeat: no-repeat;
    background-position: right center;
    background-color: transparent;
    border: none;
    box-shadow: none; }

scrolledwindow undershoot.top {
    background-color: transparent;
    background-image: linear-gradient(to left, rgba(255, 255, 255, 0.2) 50%, rgba(0, 0, 0, 0.2) 50%);
    padding-top: 1px;
    background-size: 10px 1px;
    background-repeat: repeat-x;
    background-origin: content-box;
    background-position: center top;
    border: none; }

scrolledwindow undershoot.bottom {
    background-color: transparent;
    background-image: linear-gradient(to left, rgba(255, 255, 255, 0.2) 50%, rgba(0, 0, 0, 0.2) 50%);
    padding-bottom: 1px;
    background-size: 10px 1px;
    background-repeat: repeat-x;
    background-origin: content-box;
    background-position: center bottom;
    border: none; }

scrolledwindow undershoot.left {
    background-color: transparent;
    background-image: linear-gradient(to top, rgba(255, 255, 255, 0.2) 50%, rgba(0, 0, 0, 0.2) 50%);
    padding-left: 1px;
    background-size: 1px 10px;
    background-repeat: repeat-y;
    background-origin: content-box;
    background-position: left center;
    border: none; }

scrolledwindow undershoot.right {
    background-color: transparent;
    background-image: linear-gradient(to top, rgba(255, 255, 255, 0.2) 50%, rgba(0, 0, 0, 0.2) 50%);
    padding-right: 1px;
    background-size: 1px 10px;
    background-repeat: repeat-y;
    background-origin: content-box;
    background-position: right center;
    border: none; }

scrolledwindow junction {
    border-color: transparent;
    border-image: linear-gradient(to bottom, #2b2e39 1px, transparent 1px) 0 0 0 1/0 1px stretch;
    background-color: #3e434f; }
scrolledwindow junction:dir(rtl) {
    border-image-slice: 0 1 0 0; }

separator {
    background-color: rgba(0, 0, 0, 0.1);
    min-width: 1px;
    min-height: 1px; }

list {
    background-color: @theme_bg_color;
    border-color: #2b2e39; }
list row {
    padding: 2px; }

row:not(:hover) {
    transition: all 150ms cubic-bezier(0.25, 0.46, 0.45, 0.94); }

row.activatable.has-open-popup, row.activatable:hover {
    background-color: rgba(255, 255, 255, 0.03); }

row.activatable:active {
    color: #D3DAE3; }

row.activatable:disabled {
    color: rgba(211, 218, 227, 0.45); }
row.activatable:disabled image {
    color: inherit; }

row.activatable:selected:active {
    color: #ffffff; }

row.activatable:selected.has-open-popup, row.activatable:selected:hover {
    background-color: @theme_selected_bg_color; }

.app-notification {
    padding: 10px;
    color: #BAC3CF;
    background-color: rgba(53, 57, 69, 0.95);
    background-clip: border-box;
    border-radius: 0 0 2px 2px;
    border-width: 0 1px 1px 1px;
    border-style: solid;
    border-color: rgba(31, 33, 40, 0.95); }
.app-notification border {
    border: none; }
.app-notification button {
    color: #BAC3CF;
    outline-color: rgba(186, 195, 207, 0.3);
    border-color: rgba(26, 28, 34, 0.35);
    background-color: rgba(102, 109, 132, 0.35); }
.app-notification button.flat, .app-notification button.sidebar-button {
    border-color: rgba(204, 87, 93, 0); }
.app-notification button:hover {
    color: #BAC3CF;
    outline-color: rgba(186, 195, 207, 0.3);
    border-color: rgba(26, 28, 34, 0.35);
    background-color: rgba(119, 127, 151, 0.45); }
.app-notification button:active, .app-notification button:checked {
    color: #ffffff;
    outline-color: rgba(255, 255, 255, 0.3);
    border-color: rgba(26, 28, 34, 0.35);
    background-color: @theme_selected_bg_color;
    background-clip: padding-box; }
.app-notification button:disabled {
    color: #5d626e;
    border-color: rgba(26, 28, 34, 0.35);
    background-color: rgba(102, 109, 132, 0.2); }

expander arrow {
    min-width: 16px;
    min-height: 16px;
    -gtk-icon-source: -gtk-icontheme("pan-end-symbolic"); }
expander arrow:dir(rtl) {
    -gtk-icon-source: -gtk-icontheme("pan-end-symbolic-rtl"); }
expander arrow:hover {
    color: white; }
expander arrow:checked {
    -gtk-icon-source: -gtk-icontheme("pan-down-symbolic"); }

calendar {
    color: #D3DAE3;
    border: 1px solid #2b2e39;
    border-radius: 3px;
    padding: 2px; }
calendar:selected {
    background-color: @theme_selected_bg_color;
    color: #ffffff;
    border-radius: 1.5px; }
calendar.header {
    color: #D3DAE3;
    border: none;
    border-radius: 0; }
calendar.button, calendar.button:focus {
    color: rgba(211, 218, 227, 0.45);
    border-color: transparent;
    background-color: transparent;
    background-image: none; }
calendar.button:hover, calendar.button:focus:hover {
    color: #D3DAE3; }
calendar.button:disabled, calendar.button:focus:disabled {
    color: rgba(211, 218, 227, 0.45);
    background-color: transparent;
    background-image: none; }
calendar:indeterminate {
    color: alpha(currentColor,0.55); }
calendar.highlight {
    color: #D3DAE3; }

messagedialog .titlebar {
    min-height: 20px;
    background-color: rgba(47, 52, 63, 0.97);
    border-bottom: 1px solid rgba(32, 35, 43, 0.97); }

messagedialog .dialog-action-area button {
    padding: 8px;
    min-height: 0; }

messagedialog.csd.background {
    border-bottom-left-radius: 3px;
    border-bottom-right-radius: 3px;
    border: none; }

messagedialog.csd .dialog-action-area button {
    border-bottom-style: none; }

messagedialog.csd .dialog-action-area button {
    border-radius: 0;
    border-right-style: none; }

messagedialog.csd .dialog-action-area button:last-child {
    border-radius: 0 0 3px 0;
    border-right-style: none; }

messagedialog.csd .dialog-action-area button:first-child {
    border-radius: 0 0 0 3px;
    border-left-style: none; }

messagedialog.csd .dialog-action-area button:only-child {
    border-radius: 0 0 3px 3px;
    border-left-style: none;
    border-right-style: none; }

filechooser #pathbarbox {
    border-bottom: 1px solid rgba(43, 46, 57, 0.5); }

filechooserbutton:drop(active) {
    box-shadow: none;
    border-color: transparent; }

.sidebar {
    border-style: none;
    background-color: @theme_base_color; 
}
stacksidebar.sidebar:dir(ltr) list,
stacksidebar.sidebar.left list,
stacksidebar.sidebar.left:dir(rtl) list, .sidebar:dir(ltr), .sidebar.left, .sidebar.left:dir(rtl) {
    border-right: 1px solid #2b2e39;
    border-left-style: none; }
stacksidebar.sidebar:dir(rtl) list,
stacksidebar.sidebar.right list, .sidebar:dir(rtl), .sidebar.right {
    border-left: 1px solid #2b2e39;
    border-right-style: none; }
.sidebar list {
    background-color: transparent; }
paned .sidebar.left, paned .sidebar.right, paned .sidebar.left:dir(rtl), paned .sidebar:dir(rtl), paned .sidebar:dir(ltr), paned .sidebar {
    border-style: none; }

stacksidebar row {
    padding: 10px 4px; }
stacksidebar row > label {
    padding-left: 6px;
    padding-right: 6px; }
stacksidebar row.needs-attention > label {
    background-size: 6px 6px, 0 0; }

placessidebar > viewport.frame {
    border-style: none; }

placessidebar row {
    min-height: 30px;
    padding: 0px; }
placessidebar row > revealer {
    padding: 0 10px; }
placessidebar row image.sidebar-icon:dir(ltr) {
    padding-right: 8px; }
placessidebar row image.sidebar-icon:dir(rtl) {
    padding-left: 8px; }
placessidebar row label.sidebar-label:dir(ltr) {
    padding-right: 2px; }
placessidebar row label.sidebar-label:dir(rtl) {
    padding-left: 2px; }
button.sidebar-button {
    min-width: 22px;
    min-height: 22px;
    margin-top: 2px;
    margin-bottom: 2px;
    padding: 0;
    border-radius: 100%;
    -gtk-outline-radius: 100%; }
button.sidebar-button:not(:hover):not(:active) > image {
    opacity: 0.5; }
placessidebar row.sidebar-placeholder-row {
    padding: 0 8px;
    min-height: 2px;
    background-image: linear-gradient(to top, #F08437);
    background-clip: content-box; }
placessidebar row.sidebar-new-bookmark-row {
    color: @theme_selected_bg_color; }
placessidebar row:drop(active):not(:disabled) {
    box-shadow: inset 0 1px #F08437, inset 0 -1px #F08437; }
placessidebar row:drop(active):not(:disabled), placessidebar row:drop(active):not(:disabled) label, placessidebar row:drop(active):not(:disabled) image {
    color: #F08437; }
placessidebar row:drop(active):not(:disabled):selected {
    background-color: #F08437; }
placessidebar row:drop(active):not(:disabled):selected, placessidebar row:drop(active):not(:disabled):selected label, placessidebar row:drop(active):not(:disabled):selected image {
    color: #ffffff; }

placesview .server-list-button > image {
    -gtk-icon-transform: rotate(0turn); }

placesview .server-list-button:checked > image {
    transition: 200ms cubic-bezier(0.25, 0.46, 0.45, 0.94);
    -gtk-icon-transform: rotate(-0.5turn); }

placesview > actionbar > revealer > box > label {
    padding-left: 8px;
    padding-right: 8px; }

paned > separator {
    min-width: 1px;
    min-height: 1px;
    -gtk-icon-source: none;
    border-style: none;
    background-color: transparent;
    background-image: linear-gradient(to top, #2b2e39);
    background-size: 1px 1px; }
paned > separator:selected {
    background-image: linear-gradient(to top, @theme_selected_bg_color); }
paned > separator.wide {
    min-width: 5px;
    min-height: 5px;
    background-color: #383C4A;
    background-image: linear-gradient(to top, #2b2e39), linear-gradient(to top, #2b2e39);
    background-size: 1px 1px, 1px 1px; }

paned.horizontal > separator {
	background-color:transparent;
	background-image:url("darkelements/handle-v.png");
	background-position:50% 50%;
	background-size: 6px 23px ;
	background-repeat:no-repeat;
}
paned.horizontal > separator:dir(ltr) {
    margin: 0 -8px 0 0;
    padding: 0 8px 0 0;
    background-position: left; }
paned.horizontal > separator:dir(rtl) {
    margin: 0 0 0 -8px;
    padding: 0 0 0 8px;
    background-position: right; }
paned.horizontal > separator.wide {
    margin: 0;
    padding: 0;
    background-repeat: repeat-y, repeat-y;
    background-position: left, right; }

paned.vertical > separator {
    margin: 0 0 -8px 0;
    padding: 0 0 8px 0;
    background-repeat: repeat-x;
    background-position: top; }
paned.vertical > separator.wide {
    margin: 0;
    padding: 0;
    background-repeat: repeat-x, repeat-x;
    background-position: bottom, top; }

infobar {
    border-style: none; }

.info,
.question,
.warning,
.error {
    background-color: @theme_selected_bg_color;
    color: #ffffff; }
.info label:selected:focus, .info label:selected:hover, .info label:selected,
.question label:selected:focus,
.question label:selected:hover,
.question label:selected,
.warning label:selected:focus,
.warning label:selected:hover,
.warning label:selected,
.error label:selected:focus,
.error label:selected:hover,
.error label:selected {
    color: @theme_selected_bg_color;
    background-color: #ffffff; }

.selection-mode.primary-toolbar button:hover, headerbar.selection-mode button:hover, row:selected button, .info button,
.question button,
.warning button,
.error button, .nautilus-window .floating-bar button {
    color: #ffffff;
    outline-color: rgba(255, 255, 255, 0.3);
    background-color: rgba(255, 255, 255, 0);
    border-color: rgba(255, 255, 255, 0.5); }

row:selected button.flat, row:selected button.sidebar-button, .info button.flat, .info button.sidebar-button,
.question button.flat,
.question button.sidebar-button,
.warning button.flat,
.warning button.sidebar-button,
.error button.flat,
.error button.sidebar-button, .nautilus-window .floating-bar button.flat, .nautilus-window .floating-bar button.sidebar-button {
    border-color: transparent;
    background-color: transparent;
    background-image: none;
    color: #ffffff;
    background-color: rgba(255, 255, 255, 0); }
.selection-mode.primary-toolbar button:disabled, headerbar.selection-mode button:disabled, row:selected button.flat:disabled, row:selected button.sidebar-button:disabled, .info button.flat:disabled, .info button.sidebar-button:disabled,
.question button.flat:disabled,
.question button.sidebar-button:disabled,
.warning button.flat:disabled,
.warning button.sidebar-button:disabled,
.error button.flat:disabled,
.error button.sidebar-button:disabled, .nautilus-window .floating-bar button.flat:disabled, .nautilus-window .floating-bar button.sidebar-button:disabled, .selection-mode.primary-toolbar button:disabled label, headerbar.selection-mode button:disabled label, row:selected button.flat:disabled label, row:selected button.sidebar-button:disabled label, .info button.flat:disabled label, .info button.sidebar-button:disabled label,
.question button.flat:disabled label,
.question button.sidebar-button:disabled label,
.warning button.flat:disabled label,
.warning button.sidebar-button:disabled label,
.error button.flat:disabled label,
.error button.sidebar-button:disabled label, .nautilus-window .floating-bar button.flat:disabled label, .nautilus-window .floating-bar button.sidebar-button:disabled label {
    color: rgba(255, 255, 255, 0.4); }

row:selected button:hover, .info button:hover,
.question button:hover,
.warning button:hover,
.error button:hover, .nautilus-window .floating-bar button:hover {
    color: #ffffff;
    outline-color: rgba(255, 255, 255, 0.3);
    background-color: rgba(255, 255, 255, 0.2);
    border-color: rgba(255, 255, 255, 0.8); }

.selection-mode.primary-toolbar button:active, headerbar.selection-mode button:active, .selection-mode.primary-toolbar button:checked, headerbar.selection-mode button:checked, row:selected button:active, .info button:active,
.question button:active,
.warning button:active,
.error button:active, .nautilus-window .floating-bar button:active, .selection-mode.primary-toolbar button:hover:active, headerbar.selection-mode button:hover:active, .selection-mode.primary-toolbar button:hover:checked, headerbar.selection-mode button:hover:checked, row:selected button:active:hover, .info button:active:hover,
.question button:active:hover,
.warning button:active:hover,
.error button:active:hover, .nautilus-window .floating-bar button:active:hover, row:selected button:checked, .info button:checked,
.question button:checked,
.warning button:checked,
.error button:checked, .nautilus-window .floating-bar button:checked {
    color: @theme_selected_bg_color;
    outline-color: rgba(204, 87, 93, 0.3);
    background-color: #ffffff;
    border-color: #ffffff; }

row:selected button:disabled, .info button:disabled,
.question button:disabled,
.warning button:disabled,
.error button:disabled, .nautilus-window .floating-bar button:disabled {
    background-color: rgba(255, 255, 255, 0);
    border-color: rgba(255, 255, 255, 0.4); }
row:selected button:disabled, .info button:disabled,
.question button:disabled,
.warning button:disabled,
.error button:disabled, .nautilus-window .floating-bar button:disabled, row:selected button:disabled label, .info button:disabled label,
.question button:disabled label,
.warning button:disabled label,
.error button:disabled label, .nautilus-window .floating-bar button:disabled label {
    color: rgba(255, 255, 255, 0.5); }
.selection-mode.primary-toolbar button:disabled:active, headerbar.selection-mode button:disabled:active, .selection-mode.primary-toolbar button:disabled:checked, headerbar.selection-mode button:disabled:checked, row:selected button:disabled:active, .info button:disabled:active,
.question button:disabled:active,
.warning button:disabled:active,
.error button:disabled:active, .nautilus-window .floating-bar button:disabled:active, .selection-mode.primary-toolbar button:disabled:checked, headerbar.selection-mode button:disabled:checked, .selection-mode.primary-toolbar button:disabled:active, headerbar.selection-mode button:disabled:active, row:selected button:disabled:checked, .info button:disabled:checked,
.question button:disabled:checked,
.warning button:disabled:checked,
.error button:disabled:checked, .nautilus-window .floating-bar button:disabled:checked {
    color: @theme_selected_bg_color;
    background-color: rgba(255, 255, 255, 0.5);
    border-color: rgba(255, 255, 255, 0.4); }

tooltip {
    padding: 1px;
	border: solid;
    border-image: url("darkelements/button-hover-border.png") 2 2 2 2 / 2px 2px 2px 2px stretch stretch;
    border-width:2px;
    background-color: @theme_tooltip_bg_color;
	background-image: none;
    color: @theme_tooltip_fg_color;
}

tooltip.background {
    background-color: @theme_tooltip_bg_color;;
    background-clip: padding-box; }
tooltip.background label {
    padding: 4px; 
}
tooltip decoration {
    background-color: transparent; 
}
tooltip * {
    background-color: transparent;
    color: @theme_tooltip_fg_color;
}

colorswatch, colorswatch:drop(active) {
    border-style: none; }

colorswatch.top {
    border-top-left-radius: 2.5px;
    border-top-right-radius: 2.5px; }
colorswatch.top overlay {
    border-top-left-radius: 2px;
    border-top-right-radius: 2px; }

colorswatch.bottom {
    border-bottom-left-radius: 2.5px;
    border-bottom-right-radius: 2.5px; }
colorswatch.bottom overlay {
    border-bottom-left-radius: 2px;
    border-bottom-right-radius: 2px; }

colorswatch.left, colorswatch:first-child:not(.top) {
    border-top-left-radius: 2.5px;
    border-bottom-left-radius: 2.5px; }
colorswatch.left overlay, colorswatch:first-child:not(.top) overlay {
    border-top-left-radius: 2px;
    border-bottom-left-radius: 2px; }

colorswatch.right, colorswatch:last-child:not(.bottom) {
    border-top-right-radius: 2.5px;
    border-bottom-right-radius: 2.5px; }
colorswatch.right overlay, colorswatch:last-child:not(.bottom) overlay {
    border-top-right-radius: 2px;
    border-bottom-right-radius: 2px; }

colorswatch.dark overlay {
    color: rgba(255, 255, 255, 0.7); }
colorswatch.dark overlay:hover {
    border-color: #2b2e39; }

colorswatch.light overlay {
    color: rgba(0, 0, 0, 0.7); }
colorswatch.light overlay:hover {
    border-color: #2b2e39; }

colorswatch overlay {
    border: 1px solid #2b2e39; }
colorswatch overlay:hover {
    background-color: rgba(255, 255, 255, 0.2); }

colorswatch:disabled {
    opacity: 0.5; }
colorswatch:disabled overlay {
    border-color: rgba(0, 0, 0, 0.6);
    box-shadow: none; }

colorswatch#add-color-button {
    border-style: solid;
    border-width: 1px;
    color: #D3DAE3;
    outline-color: rgba(211, 218, 227, 0.3);
    border-color: #2b2e39;
    background-color: #444a58; }
colorswatch#add-color-button:hover {
    color: #D3DAE3;
    outline-color: rgba(211, 218, 227, 0.3);
    border-color: #2b2e39;
    background-color: #505666; }
colorswatch#add-color-button overlay {
    border-color: transparent;
    background-color: transparent;
    background-image: none; }

button.color {
    padding: 0; }
button.color colorswatch:first-child:last-child, button.color colorswatch:first-child:last-child overlay {
    margin: 4px;
    border-radius: 0; }

colorchooser .popover.osd {
    border-radius: 3px; }

.content-view {
    background-color: @theme_bg_color; }
.content-view:hover {
    -gtk-icon-effect: highlight; }

.scale-popup button:hover {
    color: #D3DAE3;
    outline-color: rgba(211, 218, 227, 0.3);
    border-color: #2b2e39;
    background-color: #505666; }

.context-menu, popover.touch-selection, .csd popover.touch-selection,
popover.background.touch-selection, .csd popover.background.touch-selection {
    font: initial; }

.monospace {
    font: Monospace; }

button.circular, button.nautilus-circular-button.image-button,
button.circular-button {
    padding: 0;
    min-width: 26px;
    min-height: 26px;
    border-radius: 50%;
    -gtk-outline-radius: 50%; }
button.circular label, button.nautilus-circular-button.image-button label,
button.circular-button label {
    padding: 0; }

.keycap {
    min-width: 16px;
    min-height: 20px;
    padding: 3px 6px 4px 6px;
    color: #D3DAE3;
    background-color: @theme_bg_color;
    border: 1px solid #2b2e39;
    border-radius: 2.5px;
    box-shadow: inset 0px -2px 0px rgba(0, 0, 0, 0.15); }

stackswitcher button.text-button {
    min-width: 80px; }

stackswitcher button.circular, stackswitcher button.nautilus-circular-button.image-button {
    min-width: 0; }

*:drop(active):focus,
*:drop(active) {
    box-shadow: inset 0 0 0 1px #F08437; }

decoration {
    border-radius: 3px 3px 0 0;
    border-width: 0px;
    box-shadow: 0 0 0 1px rgba(32, 35, 43, 0.97), 0 8px 8px 0 rgba(0, 0, 0, 0.35);
    margin: 10px; }
decoration:backdrop {
    box-shadow: 0 0 0 1px rgba(32, 35, 43, 0.87), 0 8px 8px 0 transparent, 0 5px 5px 0 rgba(0, 0, 0, 0.35);
    transition: 200ms ease-out; }
.fullscreen decoration,
.tiled decoration {
    border-radius: 0; }
.popup decoration {
    box-shadow: none;
    border-radius: 0; }
.ssd decoration {
    border-radius: 3px 3px 0 0;
    box-shadow: 0 0 0 1px rgba(0, 0, 0, 0.65); }
.ssd decoration.maximized {
    border-radius: 0; }
.csd.popup decoration {
    border-radius: 2px;
    box-shadow: 0 3px 6px rgba(0, 0, 0, 0.45), 0 0 0 1px #22242d; }
tooltip.csd decoration {
    border-radius: 2px;
    box-shadow: 0 1px 3px 1px rgba(0, 0, 0, 0.25); }
messagedialog.csd decoration {
    border-radius: 3px; }
.solid-csd decoration {
    border-radius: 0;
    margin: 1px;
    background-color: rgba(47, 52, 63, 0.97);
    box-shadow: none; }

headerbar.default-decoration button.titlebutton,
.titlebar.default-decoration button.titlebutton {
    padding: 0 4px;
    min-width: 0;
    min-height: 0;
    margin: 0; }

headerbar button.titlebutton,
.titlebar button.titlebutton {
    padding: 0;
    min-width: 24px;
    border-color: transparent;
    background-color: transparent;
    background-image: none;
    background-color: rgba(47, 52, 63, 0); }
headerbar button.titlebutton:hover,
.titlebar button.titlebutton:hover {
    color: rgba(207, 218, 231, 0.8);
    outline-color: rgba(207, 218, 231, 0.1);
    border-color: rgba(21, 23, 28, 0.37);
    background-color: rgba(95, 105, 127, 0.37); }
headerbar button.titlebutton:active, headerbar button.titlebutton:checked,
.titlebar button.titlebutton:active,
.titlebar button.titlebutton:checked {
    color: #ffffff;
    outline-color: rgba(255, 255, 255, 0.3);
    border-color: transparent;
    background-color: @theme_selected_bg_color; }
headerbar button.titlebutton.close, headerbar button.titlebutton.maximize, headerbar button.titlebutton.minimize,
.titlebar button.titlebutton.close,
.titlebar button.titlebutton.maximize,
.titlebar button.titlebutton.minimize {
    color: transparent;
    background-color: transparent;
    background-position: center;
    background-repeat: no-repeat;
    border-width: 0; }
headerbar button.titlebutton.close:backdrop, headerbar button.titlebutton.maximize:backdrop, headerbar button.titlebutton.minimize:backdrop,
.titlebar button.titlebutton.close:backdrop,
.titlebar button.titlebutton.maximize:backdrop,
.titlebar button.titlebutton.minimize:backdrop {
    opacity: 1; }
headerbar button.titlebutton.close,
.titlebar button.titlebutton.close {
    background-image: -gtk-scaled(url("assets/titlebutton-close-dark.png"), url("assets/titlebutton-close-dark@2.png")); }
headerbar button.titlebutton.close:backdrop,
.titlebar button.titlebutton.close:backdrop {
    background-image: -gtk-scaled(url("assets/titlebutton-close-backdrop-dark.png"), url("assets/titlebutton-close-backdrop-dark@2.png")); }
headerbar button.titlebutton.close:hover,
.titlebar button.titlebutton.close:hover {
    background-image: -gtk-scaled(url("assets/titlebutton-close-hover-dark.png"), url("assets/titlebutton-close-hover-dark@2.png")); }
headerbar button.titlebutton.close:active,
.titlebar button.titlebutton.close:active {
    background-image: -gtk-scaled(url("assets/titlebutton-close-active-dark.png"), url("assets/titlebutton-close-active-dark@2.png")); }
headerbar button.titlebutton.maximize,
.titlebar button.titlebutton.maximize {
    background-image: -gtk-scaled(url("assets/titlebutton-maximize-dark.png"), url("assets/titlebutton-maximize-dark@2.png")); }
headerbar button.titlebutton.maximize:backdrop,
.titlebar button.titlebutton.maximize:backdrop {
    background-image: -gtk-scaled(url("assets/titlebutton-maximize-backdrop-dark.png"), url("assets/titlebutton-maximize-backdrop-dark@2.png")); }
headerbar button.titlebutton.maximize:hover,
.titlebar button.titlebutton.maximize:hover {
    background-image: -gtk-scaled(url("assets/titlebutton-maximize-hover-dark.png"), url("assets/titlebutton-maximize-hover-dark@2.png")); }
headerbar button.titlebutton.maximize:active,
.titlebar button.titlebutton.maximize:active {
    background-image: -gtk-scaled(url("assets/titlebutton-maximize-active-dark.png"), url("assets/titlebutton-maximize-active-dark@2.png")); }
headerbar button.titlebutton.minimize,
.titlebar button.titlebutton.minimize {
    background-image: -gtk-scaled(url("assets/titlebutton-minimize-dark.png"), url("assets/titlebutton-minimize-dark@2.png")); }
headerbar button.titlebutton.minimize:backdrop,
.titlebar button.titlebutton.minimize:backdrop {
    background-image: -gtk-scaled(url("assets/titlebutton-minimize-backdrop-dark.png"), url("assets/titlebutton-minimize-backdrop-dark@2.png")); }
headerbar button.titlebutton.minimize:hover,
.titlebar button.titlebutton.minimize:hover {
    background-image: -gtk-scaled(url("assets/titlebutton-minimize-hover-dark.png"), url("assets/titlebutton-minimize-hover-dark@2.png")); }
headerbar button.titlebutton.minimize:active,
.titlebar button.titlebutton.minimize:active {
    background-image: -gtk-scaled(url("assets/titlebutton-minimize-active-dark.png"), url("assets/titlebutton-minimize-active-dark@2.png")); }

.view:selected, iconview:selected, .view:selected:focus, iconview:selected:focus, .view text:selected, iconview text:selected,
textview text:selected, iconview text:selected:focus,
textview text:selected:focus, .view text selection:focus, iconview text selection:focus, .view text selection, iconview text selection,
textview text selection:focus,
textview text selection, flowbox flowboxchild:selected, entry selection:focus, entry selection, menuitem.button.flat:active, menuitem.button.flat:active arrow, menuitem.button.flat:selected, menuitem.button.flat:selected arrow,
modelbutton.flat:active,
modelbutton.flat:active arrow,
modelbutton.flat:selected,
modelbutton.flat:selected arrow, treeview.view:selected, treeview.view:selected:focus, row:selected, .nemo-window .nemo-window-pane widget.entry:selected:focus, .nemo-window .nemo-window-pane widget.entry:selected, filechooser placessidebar.sidebar row.sidebar-row.has-open-popup:selected, filechooser placessidebar.sidebar row.sidebar-row:selected, filechooser placessidebar.sidebar row.sidebar-row:selected:hover, filechooser placessidebar.sidebar row.sidebar-row:active:hover,
.nautilus-window placessidebar.sidebar row.sidebar-row.has-open-popup:selected,
.nautilus-window placessidebar.sidebar row.sidebar-row:selected,
.nautilus-window placessidebar.sidebar row.sidebar-row:selected:hover,
.nautilus-window placessidebar.sidebar row.sidebar-row:active:hover {
    background-color: @theme_selected_bg_color; }
row:selected label, label:selected, .view:selected, iconview:selected, .view:selected:focus, iconview:selected:focus, .view text:selected, iconview text:selected,
textview text:selected, iconview text:selected:focus,
textview text:selected:focus, .view text selection:focus, iconview text selection:focus, .view text selection, iconview text selection,
textview text selection:focus,
textview text selection, flowbox flowboxchild:selected, entry selection:focus, entry selection, menuitem.button.flat:active, menuitem.button.flat:active arrow, menuitem.button.flat:selected, menuitem.button.flat:selected arrow,
modelbutton.flat:active,
modelbutton.flat:active arrow,
modelbutton.flat:selected,
modelbutton.flat:selected arrow, treeview.view:selected, treeview.view:selected:focus, row:selected, .nemo-window .nemo-window-pane widget.entry:selected:focus, .nemo-window .nemo-window-pane widget.entry:selected, filechooser placessidebar.sidebar row.sidebar-row.has-open-popup:selected, filechooser placessidebar.sidebar row.sidebar-row:selected, filechooser placessidebar.sidebar row.sidebar-row:selected:hover, filechooser placessidebar.sidebar row.sidebar-row:active:hover,
.nautilus-window placessidebar.sidebar row.sidebar-row.has-open-popup:selected,
.nautilus-window placessidebar.sidebar row.sidebar-row:selected,
.nautilus-window placessidebar.sidebar row.sidebar-row:selected:hover,
.nautilus-window placessidebar.sidebar row.sidebar-row:active:hover {
    color: #ffffff;
    outline-color: rgba(255, 255, 255, 0.3); }
row:selected label:disabled, label:disabled:selected, .view:disabled:selected, iconview:disabled:selected, iconview:disabled:selected:focus, .view text:disabled:selected, iconview text:disabled:selected,
textview text:disabled:selected, iconview text selection:disabled:focus, .view text selection:disabled, iconview text selection:disabled,
textview text selection:disabled, flowbox flowboxchild:disabled:selected, label:disabled selection, entry selection:disabled, menuitem.button.flat:disabled:active, menuitem.button.flat:active arrow:disabled, menuitem.button.flat:disabled:selected, menuitem.button.flat:selected arrow:disabled,
modelbutton.flat:disabled:active,
modelbutton.flat:active arrow:disabled,
modelbutton.flat:disabled:selected,
modelbutton.flat:selected arrow:disabled, treeview.view:disabled:selected:focus, row:disabled:selected, .nemo-window .nemo-window-pane widget.entry:disabled:selected, filechooser placessidebar.sidebar row.sidebar-row:disabled:selected, filechooser placessidebar.sidebar row.sidebar-row:disabled:active:hover,
.nautilus-window placessidebar.sidebar row.sidebar-row:disabled:selected,
.nautilus-window placessidebar.sidebar row.sidebar-row:disabled:active:hover {
    color: #e6abae; }

.gedit-bottom-panel-paned notebook > header.top > tabs > tab:checked,
terminal-window notebook > header.top > tabs > tab:checked {
    box-shadow: inset 0 -1px #2b2e39; }

terminal-window notebook > header.top {
    padding-top: 3px;
    box-shadow: inset 0 1px #262a33, inset 0 -1px #2b2e39; }
terminal-window notebook > header.top button {
    padding: 0;
    min-width: 24px;
    min-height: 24px; }

.nautilus-canvas-item {
    border-radius: 2px; }

.nautilus-desktop.nautilus-canvas-item, .nemo-desktop.nemo-canvas-item, .caja-desktop {
    color: #ffffff;
    text-shadow: 1px 1px rgba(0, 0, 0, 0.6); }
.nautilus-desktop.nautilus-canvas-item:active, .nemo-desktop.nemo-canvas-item:active, .caja-desktop:active {
    color: #D3DAE3; }
.nautilus-desktop.nautilus-canvas-item:selected, .nemo-desktop.nemo-canvas-item:selected, .caja-desktop:selected {
    color: #ffffff;
    text-shadow: none; }

.nautilus-canvas-item.dim-label, label.nautilus-canvas-item.separator,
popover.background label.nautilus-canvas-item.separator, headerbar .nautilus-canvas-item.subtitle, .titlebar:not(headerbar) .nautilus-canvas-item.subtitle,
.nautilus-list-dim-label {
    color: #868b97; }
.nautilus-canvas-item.dim-label:selected, label.nautilus-canvas-item.separator:selected, headerbar .nautilus-canvas-item.subtitle:selected, .titlebar:not(headerbar) .nautilus-canvas-item.subtitle:selected, .nautilus-canvas-item.dim-label:selected:focus, label.nautilus-canvas-item.separator:selected:focus, headerbar .nautilus-canvas-item.subtitle:selected:focus, .titlebar:not(headerbar) .nautilus-canvas-item.subtitle:selected:focus,
.nautilus-list-dim-label:selected,
.nautilus-list-dim-label:selected:focus {
    color: #f5dddf; }

.nautilus-window searchbar {
    border-top: 1px solid #2b2e39; }

.nautilus-window .searchbar-container {
    margin-top: -1px; }

.nautilus-window notebook,
.nautilus-window notebook > stack:not(:only-child) searchbar {
    background-color: @theme_bg_color; }

.disk-space-display {
    border-style: solid;
    border-width: 1px; }
.disk-space-display.unknown {
    background-color: rgba(211, 218, 227, 0.5);
    border-color: rgba(180, 192, 207, 0.5); }
.disk-space-display.used {
    background-color: rgba(204, 87, 93, 0.8);
    border-color: rgba(184, 56, 62, 0.8); }
.disk-space-display.free {
    background-color: #313541;
    border-color: #1b1d24; }

@keyframes needs_attention_keyframes {
    0% {
        color: rgba(207, 218, 231, 0.8);
        outline-color: rgba(207, 218, 231, 0.1);
        border-color: rgba(21, 23, 28, 0.37);
        background-color: rgba(95, 105, 127, 0.37); }
    100% {
        color: #ffffff;
        outline-color: rgba(255, 255, 255, 0.3);
        border-color: transparent;
        background-color: @theme_selected_bg_color; } }

.nautilus-operations-button-needs-attention {
    animation: needs_attention_keyframes 2s ease-in-out; }

.nautilus-operations-button-needs-attention-multiple {
    animation: needs_attention_keyframes 3s ease-in-out;
    animation-iteration-count: 3; }

.nemo-window .nemo-places-sidebar.frame {
    border-width: 0; }

.nemo-window notebook {
    background-color: @theme_bg_color; }

.nemo-window .nemo-window-pane widget.entry {
    border: 1px solid;
    border-radius: 3px;
    color: #D3DAE3;
    border-color: #2b2e39;
    background-color: @theme_bg_color;
    background-image: linear-gradient(to bottom, @theme_bg_color);
    box-shadow: inset 1px 0 @theme_selected_bg_color, inset -1px 0 @theme_selected_bg_color, inset 0 1px @theme_selected_bg_color, inset 0 -1px @theme_selected_bg_color; }

.nemo-window .primary-toolbar widget.raised.linked:not(.vertical):not(.path-bar) > button {
    color: rgba(207, 218, 231, 0.8);
    outline-color: rgba(207, 218, 231, 0.1);
    border-color: rgba(21, 23, 28, 0.37);
    background-color: rgba(95, 105, 127, 0.37); }
.nemo-window .primary-toolbar widget.raised.linked:not(.vertical):not(.path-bar) > button:not(:last-child):not(:only-child) {
    margin: 0 0 1px 0; }
.nemo-window .primary-toolbar widget.raised.linked:not(.vertical):not(.path-bar) > button:hover {
    background-color: rgba(134, 144, 165, 0.37); }
.nemo-window .primary-toolbar widget.raised.linked:not(.vertical):not(.path-bar) > button:active, .nemo-window .primary-toolbar widget.raised.linked:not(.vertical):not(.path-bar) > button:checked {
    color: #ffffff;
    outline-color: rgba(255, 255, 255, 0.3);
    border-color: transparent;
    background-color: @theme_selected_bg_color; }
.nemo-window .primary-toolbar widget.raised.linked:not(.vertical):not(.path-bar) > button:disabled {
    color: rgba(207, 218, 231, 0.4); }

.nemo-window .primary-toolbar widget.raised.linked:not(.vertical):not(.path-bar) > button + button {
    border-left-style: none; }

.nemo-window .primary-toolbar widget.raised.linked:not(.vertical):not(.path-bar) > button:hover:not(:checked):not(:active):not(:only-child):hover {
    box-shadow: inset 1px 0 rgba(21, 23, 28, 0.37), inset -1px 0 rgba(21, 23, 28, 0.37); }

.nemo-window .primary-toolbar widget.raised.linked:not(.vertical):not(.path-bar) > button:hover:not(:checked):not(:active):not(:only-child):first-child:hover {
    box-shadow: inset -1px 0 rgba(21, 23, 28, 0.37); }

.nemo-window .primary-toolbar widget.raised.linked:not(.vertical):not(.path-bar) > button:hover:not(:checked):not(:active):not(:only-child):last-child:hover {
    box-shadow: inset 1px 0 rgba(21, 23, 28, 0.37); }

.caja-notebook {
    border-top: 1px solid #2b2e39; }

.caja-side-pane .frame {
    border-width: 1px 0 0; }

.caja-notebook .frame {
    border-width: 0 0 1px; }

.open-document-selector-treeview.view, iconview.open-document-selector-treeview {
    padding: 3px 6px 3px 6px;
    border-color: @theme_bg_color; }
.open-document-selector-treeview.view:hover, iconview.open-document-selector-treeview:hover {
    background-color: #4a4f5c; }
.open-document-selector-treeview.view:hover:selected, iconview.open-document-selector-treeview:hover:selected {
    color: #ffffff;
    background-color: @theme_selected_bg_color; }

.open-document-selector-name-label {
    color: #D3DAE3; }

.open-document-selector-path-label {
    color: #8a909b;
    font-size: smaller; }
.open-document-selector-path-label:selected {
    color: rgba(255, 255, 255, 0.9); }

.gedit-document-panel row button {
    min-width: 22px;
    min-height: 22px;
    padding: 0;
    color: transparent;
    background: none;
    border: none;
    box-shadow: none; }
.gedit-document-panel row button image {
    color: inherit; }

.gedit-document-panel row:hover:not(:selected) button {
    color: #9da3ad; }
.gedit-document-panel row:hover:not(:selected) button:hover {
    color: #ff4d4d; }
.gedit-document-panel row:hover:not(:selected) button:active {
    color: #D3DAE3; }

.gedit-document-panel row:hover:selected button:hover {
    color: #ff6666;
    background: none;
    border: none;
    box-shadow: none; }
.gedit-document-panel row:hover:selected button:hover:active {
    color: #ffffff; }

.gedit-document-panel-dragged-row {
    border: 1px solid #2b2e39;
    background-color: #22242d;
    color: #D3DAE3; }

.gedit-side-panel-paned statusbar {
    border-top: 1px solid #2b2e39;
    background-color: #383C4A; }

.gedit-search-slider {
    background-color: #3c4150;
    padding: 6px;
    border-color: #2b2e39;
    border-radius: 0 0 2px 2px;
    border-width: 0 1px 1px 1px;
    border-style: solid; }

.gedit-search-entry-occurrences-tag {
    color: rgba(211, 218, 227, 0.6);
    border: none;
    margin: 2px;
    padding: 2px; }

.gb-search-entry-occurrences-tag {
    background: none; }

workbench.csd > stack.titlebar:not(headerbar) {
    padding: 0;
    background: none;
    border: none;
    box-shadow: none; }
workbench.csd > stack.titlebar:not(headerbar) headerbar, workbench.csd > stack.titlebar:not(headerbar) headerbar:first-child, workbench.csd > stack.titlebar:not(headerbar) headerbar:last-child {
    border-radius: 3px 3px 0 0; }

editortweak .linked > entry.search:focus + .gb-linked-scroller {
    border-top-color: @theme_selected_bg_color; }

layouttab {
    background-color: @theme_bg_color; }

layout {
    border: 1px solid #2b2e39;
    -PnlDockBin-handle-size: 1; }

eggsearchbar box.search-bar {
    border-bottom: 1px solid #2b2e39; }

pillbox {
    color: #ffffff;
    background-color: @theme_selected_bg_color;
    border-radius: 3px; }

docktabstrip {
    padding: 0 6px;
    background-color: #383C4A;
    border-bottom: 1px solid #2b2e39; }
docktabstrip docktab {
    min-height: 28px;
    border: solid transparent;
    border-width: 0 1px; }
docktabstrip docktab label {
    opacity: 0.5; }
docktabstrip docktab:checked label, docktabstrip docktab:hover label {
    opacity: 1; }
docktabstrip docktab:checked {
    border-color: #2b2e39;
    background-color: @theme_bg_color; }

dockbin {
    border: 1px solid #2b2e39;
    -PnlDockBin-handle-size: 1; }

dockpaned {
    border: 1px solid #2b2e39; }

dockoverlayedge {
    background-color: #383C4A; }
dockoverlayedge docktabstrip {
    padding: 0;
    border: none; }
dockoverlayedge.left-edge tab:checked,
dockoverlayedge.right-edge tab:checked {
    border-width: 1px 0; }

.documents-scrolledwin.frame {
    border-width: 0; }

button.documents-load-more {
    border-width: 1px 0 0;
    border-radius: 0; }

.documents-icon-bg {
    background-color: @theme_selected_bg_color;
    color: #ffffff;
    border-radius: 2px; }

.documents-collection-icon, .photos-collection-icon {
    background-color: rgba(211, 218, 227, 0.3);
    border-radius: 2px; }

button.documents-favorite:active,
button.documents-favorite:active:hover {
    color: #e4a5a8; }

.documents-entry-tag, .photos-entry-tag {
    color: #ffffff;
    background: @theme_selected_bg_color;
    border-radius: 2px;
    border-width: 0;
    margin: 2px;
    padding: 4px; }
.documents-entry-tag:hover, .photos-entry-tag:hover {
    color: #ffffff;
    background: #d1676c; }
.documents-entry-tag:active, .photos-entry-tag:active {
    color: #ffffff;
    background: #c7474e; }

.content-view.document-page {
    border-style: solid;
    border-width: 3px 3px 6px 4px;
    border-image: url("assets/thumbnail-frame.png") 3 3 6 4; }

.photos-fade-in {
    opacity: 1.0;
    transition: opacity 0.2s ease-out; }

.photos-fade-out {
    opacity: 0.0;
    transition: opacity 0.2s ease-out; }

.tr-workarea undershoot,
.tr-workarea overshoot {
    border-color: transparent; }

.gnome-panel-menu-bar, .gnome-panel-menu-bar menubar,
.mate-panel-menu-bar,
.mate-panel-menu-bar menubar {
    background-color: rgba(43, 46, 55, 0.95); }

.gnome-panel-menu-bar menubar,
.gnome-panel-menu-bar #PanelApplet label,
.gnome-panel-menu-bar #PanelApplet image,
.mate-panel-menu-bar menubar,
.mate-panel-menu-bar #PanelApplet label,
.mate-panel-menu-bar #PanelApplet image {
    color: #BAC3CF; }

.gnome-panel-menu-bar button label, .gnome-panel-menu-bar button image,
.gnome-panel-menu-bar #tasklist-button label,
.gnome-panel-menu-bar #tasklist-button image,
.mate-panel-menu-bar button label,
.mate-panel-menu-bar button image,
.mate-panel-menu-bar #tasklist-button label,
.mate-panel-menu-bar #tasklist-button image {
    color: inherit; }

.gnome-panel-menu-bar .wnck-pager,
.mate-panel-menu-bar .wnck-pager {
    color: #5d6268;
    background-color: rgba(20, 22, 27, 0.95); }
.gnome-panel-menu-bar .wnck-pager:hover,
.mate-panel-menu-bar .wnck-pager:hover {
    background-color: rgba(54, 58, 70, 0.95); }
.gnome-panel-menu-bar .wnck-pager:selected,
.mate-panel-menu-bar .wnck-pager:selected {
    color: #e4a5a8;
    background-color: @theme_selected_bg_color; }

.gnome-panel-menu-bar na-tray-applet,
.mate-panel-menu-bar na-tray-applet {
    -NaTrayApplet-icon-padding: 0;
    -NaTrayApplet-icon-size: 16px; }

.xfce4-panel.panel {
    background-color: rgba(43, 46, 55, 0.95);
    text-shadow: none;
    -gtk-icon-shadow: none; }

#tasklist-button {
    color: rgba(186, 195, 207, 0.8);
    border-radius: 0;
    border: none;
    background-color: rgba(43, 46, 55, 0); }
#tasklist-button:hover {
    color: #d8dde4;
    background-color: rgba(0, 0, 0, 0.17); }
#tasklist-button:checked {
    color: #ffffff;
    background-color: rgba(0, 0, 0, 0.25);
    box-shadow: inset 0 -2px @theme_selected_bg_color; }

.gnome-panel-menu-bar button:not(#tasklist-button),
.mate-panel-menu-bar button:not(#tasklist-button), .xfce4-panel.panel button.flat, .xfce4-panel.panel button.sidebar-button {
    color: #BAC3CF;
    border-radius: 0;
    border: none;
    background-color: rgba(43, 46, 55, 0); }
.gnome-panel-menu-bar button:hover:not(#tasklist-button),
.mate-panel-menu-bar button:hover:not(#tasklist-button), .xfce4-panel.panel button.flat:hover, .xfce4-panel.panel button.sidebar-button:hover {
    border: none;
    background-color: rgba(65, 70, 84, 0.95); }
.gnome-panel-menu-bar button:active:not(#tasklist-button),
.mate-panel-menu-bar button:active:not(#tasklist-button), .xfce4-panel.panel button.flat:active, .xfce4-panel.panel button.sidebar-button:active, .gnome-panel-menu-bar button:checked:not(#tasklist-button),
.mate-panel-menu-bar button:checked:not(#tasklist-button), .xfce4-panel.panel button.flat:checked, .xfce4-panel.panel button.sidebar-button:checked {
    color: #ffffff;
    border: none;
    background-color: @theme_selected_bg_color; }

.nautilus-window .floating-bar {
    padding: 1px;
    background-color: @theme_selected_bg_color;
    color: #ffffff;
    border-radius: 2px 2px 0 0; }
.nautilus-window .floating-bar.bottom.left {
    border-top-left-radius: 0; }
.nautilus-window .floating-bar.bottom.right {
    border-top-right-radius: 0; }
.nautilus-window .floating-bar button {
    border: none;
    border-radius: 0;
    min-height: 0; }

.marlin-pathbar.pathbar {
    border-radius: 3px;
    padding-left: 4px;
    padding-right: 4px;
    color: rgba(207, 218, 231, 0.8);
    border-color: rgba(21, 23, 28, 0.37);
    background-image: linear-gradient(to bottom, rgba(95, 105, 127, 0.37));
    background-color: transparent; }
.marlin-pathbar.pathbar image, .marlin-pathbar.pathbar image:hover {
    color: inherit; }
.marlin-pathbar.pathbar:focus {
    color: #ffffff;
    border-color: transparent;
    background-image: linear-gradient(to bottom, @theme_selected_bg_color); }
.marlin-pathbar.pathbar:disabled {
    color: rgba(207, 218, 231, 0.35);
    background-image: linear-gradient(to bottom, rgba(95, 105, 127, 0.22)); }
.marlin-pathbar.pathbar:active, .marlin-pathbar.pathbar:checked {
    color: @theme_selected_bg_color; }

.gala-notification {
    border: 1px solid rgba(0, 0, 0, 0.35);
    border-radius: 3px;
    box-shadow: 0 2px 4px rgba(0, 0, 0, 0.2);
    background-image: linear-gradient(to bottom, white);
    background-color: transparent; }
.gala-notification .title, .gala-notification .label {
    color: #5c616c; }

.panel {
    background-color: transparent;
    color: white;
    font-weight: bold;
    text-shadow: 0 1px 2px rgba(0, 0, 0, 0.6);
    -gtk-icon-shadow: 0 1px 2px rgba(0, 0, 0, 0.6); }
.panel-shadow {
    background-image: none;
    background-color: transparent; }
.panel .menu {
    box-shadow: none; }
.panel .menu .menuitem {
    font-weight: normal;
    text-shadow: none;
    -gtk-icon-shadow: none; }
.panel .menu .window-frame.menu.csd,
.panel .menu .window-frame.popup.csd {
    box-shadow: 0 0 0 1px rgba(0, 0, 0, 0.2), 0 10px 20px rgba(0, 0, 0, 0.19), 0 6px 6px rgba(0, 0, 0, 0.23); }
.panel .menubar > .menuitem {
    padding: 3px 6px; }
.panel .menubar > .menuitem:hover {
    background-color: transparent; }
.panel .window-frame.menu.csd,
.panel .window-frame.popup.csd {
    box-shadow: none; }

.composited-indicator {
    background-color: transparent;
    color: white;
    text-shadow: 0 1px 2px rgba(0, 0, 0, 0.6);
    -gtk-icon-shadow: 0 1px 2px rgba(0, 0, 0, 0.6); }
.composited-indicator > GtkWidget > GtkWidget:first-child {
    padding: 0 2px; }
.composited-indicator .menuitem:active, .composited-indicator .menuitem:hover {
    border-style: none;
    background-image: none;
    box-shadow: none; }
.composited-indicator > .popup > .menu {
    padding-top: 8px;
    padding-bottom: 8px; }

.panel-app-button > GtkWidget > GtkWidget:first-child {
    padding: 0 2px 0 4px; }

.panel .menu .spinner,
.menu .spinner {
    opacity: 1; }

UnityDecoration {
    -UnityDecoration-extents: 28px 1 1 1;
    -UnityDecoration-input-extents: 10px;
    -UnityDecoration-shadow-offset-x: 0px;
    -UnityDecoration-shadow-offset-y: 3px;
    -UnityDecoration-active-shadow-color: rgba(0, 0, 0, 0.2);
    -UnityDecoration-active-shadow-radius: 12px;
    -UnityDecoration-inactive-shadow-color: rgba(0, 0, 0, 0.07);
    -UnityDecoration-inactive-shadow-radius: 7px;
    -UnityDecoration-glow-size: 10px;
    -UnityDecoration-glow-color: @theme_selected_bg_color;
    -UnityDecoration-title-indent: 10px;
    -UnityDecoration-title-fade: 35px;
    -UnityDecoration-title-alignment: 0.0; }
UnityDecoration.top {
    border: 1px solid rgba(32, 35, 43, 0.97);
    border-bottom-width: 0;
    border-radius: 4px 4px 0 0;
    padding: 1px 6px 0 6px;
    background-image: linear-gradient(to bottom, #2f343f);
    color: rgba(207, 218, 231, 0.8);
    box-shadow: inset 0 1px rgba(54, 59, 72, 0.97); }
UnityDecoration.top:backdrop {
    border-bottom-width: 0;
    color: rgba(207, 218, 231, 0.5); }
UnityDecoration.left, UnityDecoration.right, UnityDecoration.bottom, UnityDecoration.left:backdrop, UnityDecoration.right:backdrop, UnityDecoration.bottom:backdrop {
    background-color: transparent;
    background-image: linear-gradient(to bottom, rgba(32, 35, 43, 0.97)); }

UnityPanelWidget,
.unity-panel {
    background-image: linear-gradient(to bottom, #2f343f);
    color: #f6f7f9;
    box-shadow: none; }
UnityPanelWidget:backdrop,
.unity-panel:backdrop {
    color: #bdc6d1; }

.unity-panel.menubar.menuitem:hover,
.unity-panel.menubar .menuitem *:hover {
    border-radius: 0;
    color: #ffffff;
    background-image: linear-gradient(to bottom, @theme_selected_bg_color);
    border-bottom: none; }

.lightdm.menu {
    background-image: none;
    background-color: rgba(0, 0, 0, 0.4);
    border-color: rgba(255, 255, 255, 0.8);
    border-radius: 4px;
    padding: 1px;
    color: white; }

.lightdm-combo .menu {
    background-color: rgba(64, 71, 86, 0.97);
    border-radius: 0px;
    padding: 0px;
    color: white; }

.lightdm.menu .menuitem *,
.lightdm.menu .menuitem.check:active,
.lightdm.menu .menuitem.radio:active {
    color: white; }

.lightdm.menubar {
    color: rgba(255, 255, 255, 0.8);
    background-image: none;
    background-color: rgba(0, 0, 0, 0.5); }
.lightdm.menubar > .menuitem {
    padding: 2px 6px; }

.lightdm-combo.combobox-entry .button,
.lightdm-combo .cell,
.lightdm-combo .button,
.lightdm-combo .entry,
.lightdm.button,
.lightdm.entry {
    background-image: none;
    background-color: rgba(0, 0, 0, 0.3);
    border-color: rgba(255, 255, 255, 0.4);
    border-radius: 10px;
    padding: 7px;
    color: white;
    text-shadow: none; }

.lightdm.button,
.lightdm.button:hover,
.lightdm.button:active,
.lightdm.button:active:focus,
.lightdm.entry,
.lightdm.entry:hover,
.lightdm.entry:active,
.lightdm.entry:active:focus {
    background-image: none;
    border-image: none; }

.lightdm.button:focus,
.lightdm.entry:focus {
    border-color: rgba(255, 255, 255, 0.1);
    border-width: 1px;
    border-style: solid;
    color: white; }

.lightdm.entry:selected {
    background-color: rgba(255, 255, 255, 0.8); }

.lightdm.entry:active {
    -gtk-icon-source: -gtk-icontheme("process-working-symbolic");
    animation: dashentry_spinner 1s infinite linear; }

.lightdm.option-button {
    padding: 2px;
    background: none;
    border: 0; }

.lightdm.toggle-button {
    background: none;
    border-width: 0; }
.lightdm.toggle-button.selected {
    background-color: rgba(0, 0, 0, 0.7);
    border-width: 1px; }

@keyframes dashentry_spinner {
    to {
        -gtk-icon-transform: rotate(1turn); } }

.overlay-bar {
    background-color: @theme_selected_bg_color;
    border-color: @theme_selected_bg_color;
    border-radius: 2px;
    padding: 3px 6px;
    margin: 3px; }
.overlay-bar label {
    color: #ffffff; }

GraniteWidgetsThinPaned {
    background-color: transparent;
    background-image: none;
    margin: 0;
    border-left: 1px solid #2b2e39;
    border-right: 1px solid #2b2e39; }

GraniteWidgetsPopOver .frame,
GraniteWidgetsStaticNotebook .frame {
    border: none; }

.help_button {
    border-radius: 100px;
    padding: 3px 9px; }

toolbar.secondary-toolbar, .secondary-toolbar.inline-toolbar {
    padding: 3px;
    border-bottom: 1px solid #2b2e39; }
toolbar.secondary-toolbar button, .secondary-toolbar.inline-toolbar button {
    padding: 0 3px 0 3px; }

toolbar.bottom-toolbar, .bottom-toolbar.inline-toolbar {
    padding: 5px;
    border-width: 1px 0 0 0;
    border-style: solid;
    border-color: #2b2e39;
    background-color: #383C4A; }
toolbar.bottom-toolbar button, .bottom-toolbar.inline-toolbar button {
    padding: 2px 3px 2px 3px; }

.source-list {
    -GtkTreeView-horizontal-separator: 1px;
    -GtkTreeView-vertical-separator: 6px; }

.source-list,
.source-list.view,
iconview.source-list {
    background-color: #383C4A;
    color: #D3DAE3;
    -gtk-icon-style: regular; }

.source-list.category-expander {
    color: transparent; }

.source-list.view:hover, iconview.source-list:hover {
    background-color: #434859; }

.source-list.view:selected, iconview.source-list:selected,
.source-list.view:hover:selected,
iconview.source-list:hover:selected,
.source-list.view:selected:focus,
iconview.source-list:selected:focus,
.source-list.category-expander:hover {
    color: #ffffff;
    background-color: @theme_selected_bg_color; }

.source-list scrollbar,
.source-list junction {
    border-image: none;
    border-color: transparent;
    background-color: #383C4A;
    background-image: none; }

.source-list.badge,
.source-list.badge:hover,
.source-list.badge:selected,
.source-list.badge:selected:focus,
.source-list.badge:hover:selected {
    background-image: none;
    background-color: @theme_selected_bg_color;
    color: #ffffff;
    border-radius: 10px;
    padding: 0 6px;
    margin: 0 3px;
    border-width: 0; }

.source-list.badge:selected,
.source-list.badge:selected:focus,
.source-list.badge:hover:selected {
    background-color: #ffffff;
    color: @theme_selected_bg_color; }

.source-list.category-expander {
    color: #D3DAE3;
    -gtk-icon-source: -gtk-icontheme("pan-end-symbolic");
    -GtkTreeView-expander-size: 16; }

.source-list.category-expander,
.source-list.category-expander:backdrop {
    color: transparent;
    border: none; }

.source-list.category-expander:checked {
    -gtk-icon-source: -gtk-icontheme("pan-down-symbolic"); }

GraniteWidgetsWelcome {
    background-color: @theme_bg_color; }

GraniteWidgetsWelcome label {
    color: #868b97;
    font: open sans 11;
    text-shadow: none; }

GraniteWidgetsWelcome .h1,
GraniteWidgetsWelcome .h3 {
    color: rgba(211, 218, 227, 0.8); }

.help_button {
    border-radius: 0; }

GraniteWidgetsPopOver {
    -GraniteWidgetsPopOver-arrow-width: 21;
    -GraniteWidgetsPopOver-arrow-height: 10;
    -GraniteWidgetsPopOver-border-radius: 2px;
    -GraniteWidgetsPopOver-border-width: 1;
    -GraniteWidgetsPopOver-shadow-size: 12;
    border: 1px solid rgba(0, 0, 0, 0.3);
    margin: 0; }

.popover_bg {
    background-image: linear-gradient(to bottom, @theme_bg_color);
    border: 1px solid rgba(0, 0, 0, 0.3); }

GraniteWidgetsPopOver .sidebar.view, GraniteWidgetsPopOver iconview.sidebar,
GraniteWidgetsPopOver * {
    background-color: transparent; }

GraniteWidgetsXsEntry entry {
    padding: 4px; }

.h1 {
    font: open sans 24px; }

.h2 {
    font: open sans light 18px; }

.h3 {
    font: open sans 11px; }

.h4,
.category-label {
    color: #a5abb5;
    font-weight: 600; }

.h4 {
    padding-bottom: 6px;
    padding-top: 6px; }

GtkListBox .h4 {
    padding-left: 6px; }

#panel_window {
    background-color: rgba(43, 46, 55, 0.95);
    color: #BAC3CF;
    font: bold;
    box-shadow: inset 0 -1px rgba(27, 29, 35, 0.95); }
#panel_window menubar,
#panel_window menubar > menuitem {
    background-color: transparent;
    color: #BAC3CF;
    font: bold; }
#panel_window menubar menuitem:disabled {
    color: rgba(186, 195, 207, 0.5); }
#panel_window menubar menuitem:disabled label {
    color: inherit; }
#panel_window menubar menu > menuitem {
    font: normal; }

#login_window,
#shutdown_dialog,
#restart_dialog {
    font: normal;
    border-style: none;
    background-color: transparent;
    color: #D3DAE3; }

#content_frame {
    padding-bottom: 14px;
    background-color: #383C4A;
    border-top-left-radius: 2px;
    border-top-right-radius: 2px;
    border: solid rgba(0, 0, 0, 0.1);
    border-width: 1px 1px 0 1px; }

#content_frame button {
    color: #D3DAE3;
    outline-color: rgba(211, 218, 227, 0.3);
    border-color: #2b2e39;
    background-color: #444a58; }
#content_frame button:hover {
    color: #D3DAE3;
    outline-color: rgba(211, 218, 227, 0.3);
    border-color: #2b2e39;
    background-color: #505666; }
#content_frame button:active, #content_frame button:checked {
    color: #ffffff;
    outline-color: rgba(255, 255, 255, 0.3);
    border-color: #2b2e39;
    background-color: @theme_selected_bg_color; }
#content_frame button:disabled {
    border-color: rgba(43, 46, 57, 0.55);
    background-color: rgba(68, 74, 88, 0.55); }
#content_frame button:disabled label, #content_frame button:disabled {
    color: rgba(211, 218, 227, 0.45); }

#buttonbox_frame {
    padding-top: 20px;
    padding-bottom: 0px;
    border-style: none;
    background-color: rgba(47, 52, 63, 0.97);
    border-bottom-left-radius: 3px;
    border-bottom-right-radius: 3px;
    border: solid rgba(0, 0, 0, 0.1);
    border-width: 0 1px 1px 1px;
    box-shadow: inset 0 1px rgba(38, 42, 51, 0.97); }

#buttonbox_frame button {
    color: #BAC3CF;
    outline-color: rgba(186, 195, 207, 0.3);
    border-color: rgba(26, 28, 34, 0.35);
    background-color: rgba(102, 109, 132, 0.35); }
#buttonbox_frame button:hover {
    color: #BAC3CF;
    outline-color: rgba(186, 195, 207, 0.3);
    border-color: rgba(26, 28, 34, 0.35);
    background-color: rgba(119, 127, 151, 0.45); }
#buttonbox_frame button:active, #buttonbox_frame button:checked {
    color: #ffffff;
    outline-color: rgba(255, 255, 255, 0.3);
    border-color: rgba(26, 28, 34, 0.35);
    background-color: @theme_selected_bg_color; }
#buttonbox_frame button:disabled {
    color: #5d626e;
    border-color: rgba(26, 28, 34, 0.35);
    background-color: rgba(102, 109, 132, 0.2); }

#login_window #user_combobox {
    color: #D3DAE3;
    font: 13px; }
#login_window #user_combobox menu {
    font: normal; }

#user_image {
    padding: 3px;
    border-radius: 2px; }

#shutdown_button.button {
    background-clip: border-box;
    color: #ffffff;
    outline-color: rgba(255, 255, 255, 0.3);
    background-color: #F04A50;
    border-color: #F04A50; }
#shutdown_button.button:hover {
    background-clip: border-box;
    color: #ffffff;
    outline-color: rgba(255, 255, 255, 0.3);
    background-color: #f4797e;
    border-color: #f4797e; }
#shutdown_button.button:active, #shutdown_button.button:checked {
    background-clip: border-box;
    color: #ffffff;
    outline-color: rgba(255, 255, 255, 0.3);
    background-color: #ec1b22;
    border-color: #ec1b22; }

#restart_button.button {
    background-clip: border-box;
    color: #ffffff;
    outline-color: rgba(255, 255, 255, 0.3);
    background-color: #be3941;
    border-color: #be3941; }
#restart_button.button:hover {
    background-clip: border-box;
    color: #ffffff;
    outline-color: rgba(255, 255, 255, 0.3);
    background-color: #ce5c63;
    border-color: #ce5c63; }
#restart_button.button:active, #restart_button.button:checked {
    background-clip: border-box;
    color: #ffffff;
    outline-color: rgba(255, 255, 255, 0.3);
    background-color: #972d34;
    border-color: #972d34; }

#greeter_infobar {
    border-bottom-width: 0;
    font: bold; }

.nautilus-window paned > separator {
    background-image: linear-gradient(to top, rgba(42, 45, 55, 0.95)); }

filechooser paned > separator {
    background-image: linear-gradient(to top, rgba(42, 45, 55, 0.95)); }

filechooser.csd.background, filechooser placessidebar list,
.nautilus-window.csd.background,
.nautilus-window placessidebar list {
    background-color: transparent; }

filechooser placessidebar.sidebar,
.nautilus-window placessidebar.sidebar {
    background-color: rgba(53, 57, 69, 0.95); }
filechooser placessidebar.sidebar row.sidebar-row,
.nautilus-window placessidebar.sidebar row.sidebar-row {
    border: none;
    color: #BAC3CF; }
filechooser placessidebar.sidebar row.sidebar-row .sidebar-icon,
.nautilus-window placessidebar.sidebar row.sidebar-row .sidebar-icon {
    color: rgba(186, 195, 207, 0.6); }
filechooser placessidebar.sidebar row.sidebar-row.has-open-popup, filechooser placessidebar.sidebar row.sidebar-row:hover,
.nautilus-window placessidebar.sidebar row.sidebar-row.has-open-popup,
.nautilus-window placessidebar.sidebar row.sidebar-row:hover {
    background-color: rgba(186, 195, 207, 0.15); }
filechooser placessidebar.sidebar row.sidebar-row:disabled, filechooser placessidebar.sidebar row.sidebar-row:disabled label, filechooser placessidebar.sidebar row.sidebar-row:disabled image,
.nautilus-window placessidebar.sidebar row.sidebar-row:disabled,
.nautilus-window placessidebar.sidebar row.sidebar-row:disabled label,
.nautilus-window placessidebar.sidebar row.sidebar-row:disabled image {
    color: rgba(186, 195, 207, 0.4); }
filechooser placessidebar.sidebar row.sidebar-row:selected.has-open-popup .sidebar-icon, filechooser placessidebar.sidebar row.sidebar-row:selected .sidebar-icon, filechooser placessidebar.sidebar row.sidebar-row:selected:hover .sidebar-icon, filechooser placessidebar.sidebar row.sidebar-row:active:hover .sidebar-icon,
.nautilus-window placessidebar.sidebar row.sidebar-row:selected.has-open-popup .sidebar-icon,
.nautilus-window placessidebar.sidebar row.sidebar-row:selected .sidebar-icon,
.nautilus-window placessidebar.sidebar row.sidebar-row:selected:hover .sidebar-icon,
.nautilus-window placessidebar.sidebar row.sidebar-row:active:hover .sidebar-icon {
    color: inherit; }
filechooser placessidebar.sidebar row.sidebar-row:not(:selected) button.sidebar-button,
.nautilus-window placessidebar.sidebar row.sidebar-row:not(:selected) button.sidebar-button {
    color: #BAC3CF; }
filechooser placessidebar.sidebar row.sidebar-row:not(:selected) button.sidebar-button:hover,
.nautilus-window placessidebar.sidebar row.sidebar-row:not(:selected) button.sidebar-button:hover {
    color: #BAC3CF;
    outline-color: rgba(186, 195, 207, 0.3);
    border-color: rgba(26, 28, 34, 0.35);
    background-color: rgba(119, 127, 151, 0.45); }
filechooser placessidebar.sidebar row.sidebar-row:not(:selected) button.sidebar-button:active,
.nautilus-window placessidebar.sidebar row.sidebar-row:not(:selected) button.sidebar-button:active {
    color: #ffffff;
    outline-color: rgba(255, 255, 255, 0.3);
    border-color: #2b2e39;
    background-color: @theme_selected_bg_color; }
filechooser placessidebar.sidebar row.sidebar-row:not(:selected) button.sidebar-button:not(:hover):not(:active) > image,
.nautilus-window placessidebar.sidebar row.sidebar-row:not(:selected) button.sidebar-button:not(:hover):not(:active) > image {
    opacity: 0.5; }
filechooser placessidebar.sidebar row.sidebar-row.sidebar-new-bookmark-row,
.nautilus-window placessidebar.sidebar row.sidebar-row.sidebar-new-bookmark-row {
    color: @theme_selected_bg_color; }
filechooser placessidebar.sidebar row.sidebar-row.sidebar-new-bookmark-row .sidebar-icon,
.nautilus-window placessidebar.sidebar row.sidebar-row.sidebar-new-bookmark-row .sidebar-icon {
    color: inherit; }
filechooser placessidebar.sidebar row.sidebar-row:drop(active):not(:disabled), filechooser placessidebar.sidebar row.sidebar-row:drop(active):not(:disabled) label, filechooser placessidebar.sidebar row.sidebar-row:drop(active):not(:disabled) .sidebar-icon,
.nautilus-window placessidebar.sidebar row.sidebar-row:drop(active):not(:disabled),
.nautilus-window placessidebar.sidebar row.sidebar-row:drop(active):not(:disabled) label,
.nautilus-window placessidebar.sidebar row.sidebar-row:drop(active):not(:disabled) .sidebar-icon {
    color: #F08437; }
filechooser placessidebar.sidebar row.sidebar-row:drop(active):not(:disabled):selected,
.nautilus-window placessidebar.sidebar row.sidebar-row:drop(active):not(:disabled):selected {
    background-color: #F08437; }
filechooser placessidebar.sidebar row.sidebar-row:drop(active):not(:disabled):selected, filechooser placessidebar.sidebar row.sidebar-row:drop(active):not(:disabled):selected label, filechooser placessidebar.sidebar row.sidebar-row:drop(active):not(:disabled):selected .sidebar-icon,
.nautilus-window placessidebar.sidebar row.sidebar-row:drop(active):not(:disabled):selected,
.nautilus-window placessidebar.sidebar row.sidebar-row:drop(active):not(:disabled):selected label,
.nautilus-window placessidebar.sidebar row.sidebar-row:drop(active):not(:disabled):selected .sidebar-icon {
    color: #ffffff; }
filechooser placessidebar.sidebar separator,
.nautilus-window placessidebar.sidebar separator {
    background-color: transparent; }

filechooser.maximized placessidebar.sidebar,
.nautilus-window.maximized placessidebar.sidebar {
    background-color: #353945; }

.nemo-window .sidebar {
    color: #BAC3CF;
    background-color: rgba(53, 57, 69, 0.95); }
.nemo-window .sidebar .view, .nemo-window .sidebar iconview, .nemo-window .sidebar row {
    background-color: transparent;
    color: #BAC3CF; }
.nemo-window .sidebar .view.cell:selected, .nemo-window .sidebar iconview.cell:selected, .nemo-window .sidebar row.cell:selected {
    background-color: @theme_selected_bg_color;
    color: #ffffff; }
.nemo-window .sidebar .view.expander, .nemo-window .sidebar iconview.expander, .nemo-window .sidebar row.expander {
    color: rgba(123, 129, 141, 0.975); }
.nemo-window .sidebar .view.expander:hover, .nemo-window .sidebar iconview.expander:hover, .nemo-window .sidebar row.expander:hover {
    color: #BAC3CF; }
.nemo-window .sidebar separator {
    background-color: transparent; }

.caja-side-pane,
.caja-side-pane > notebook > stack > widget > box,
.caja-side-pane text,
.caja-side-pane treeview {
    color: #BAC3CF;
    caret-color: #BAC3CF;
    background-color: #353945; }

.caja-side-pane > box button:not(:active):not(:checked) {
    color: #BAC3CF; }

.caja-side-pane .frame {
    border-color: #2a2d37; }

.caja-side-pane junction {
    background-color: rgba(42, 45, 55, 0.95); }

filechooser actionbar {
    color: #BAC3CF;
    background-color: rgba(53, 57, 69, 0.95);
    border-color: rgba(20, 21, 26, 0.95); }
filechooser actionbar label, filechooser actionbar combobox {
    color: #BAC3CF; }

.gedit-bottom-panel-paned {
    background-color: @theme_bg_color; }

.gedit-document-panel {
    background-color: rgba(53, 57, 69, 0.95); }
.maximized .gedit-document-panel {
    background-color: #353945; }
.gedit-document-panel row {
    color: #BAC3CF;
    background-color: rgba(186, 195, 207, 0); }
.gedit-document-panel row:hover {
    background-color: rgba(186, 195, 207, 0.15); }
.gedit-document-panel row:active {
    color: #ffffff;
    background-color: @theme_selected_bg_color; }
.gedit-document-panel row:active button {
    color: #ffffff; }
.gedit-document-panel row:selected, .gedit-document-panel row:selected:hover {
    color: #ffffff;
    background-color: @theme_selected_bg_color; }
.gedit-document-panel row:hover:not(:selected) button:active {
    color: #BAC3CF; }

filechooser actionbar button {
    color: #BAC3CF;
    outline-color: rgba(186, 195, 207, 0.3);
    border-color: rgba(26, 28, 34, 0.35);
    background-color: rgba(102, 109, 132, 0.35); }
.caja-side-pane > box button:hover:not(:active), filechooser actionbar button:hover {
    color: #BAC3CF;
    outline-color: rgba(186, 195, 207, 0.3);
    border-color: rgba(26, 28, 34, 0.35);
    background-color: rgba(119, 127, 151, 0.45); }
filechooser actionbar button:active, filechooser actionbar button:checked {
    color: #ffffff;
    outline-color: rgba(255, 255, 255, 0.3);
    border-color: rgba(26, 28, 34, 0.35);
    background-color: @theme_selected_bg_color; }
filechooser actionbar button:disabled {
    color: #5d626e;
    border-color: rgba(26, 28, 34, 0.35);
    background-color: rgba(102, 109, 132, 0.2); }

filechooser actionbar entry {
    color: #BAC3CF;
    border-color: rgba(26, 28, 34, 0.35);
    background-image: linear-gradient(to bottom, rgba(102, 109, 132, 0.35));
    background-color: transparent; }
filechooser actionbar entry image, filechooser actionbar entry image:hover {
    color: inherit; }
filechooser actionbar entry:focus {
    color: #ffffff;
    border-color: rgba(26, 28, 34, 0.35);
    background-image: linear-gradient(to bottom, @theme_selected_bg_color); }
filechooser actionbar entry:disabled {
    color: rgba(186, 195, 207, 0.55);
    background-image: linear-gradient(to bottom, rgba(102, 109, 132, 0.2)); }

filechooser placessidebar.sidebar scrollbar,
.nautilus-window placessidebar.sidebar scrollbar, .nemo-window .sidebar scrollbar, .caja-side-pane scrollbar {
    border-color: rgba(42, 45, 55, 0.95); }
filechooser placessidebar.sidebar scrollbar.overlay-indicator:not(.dragging):not(.hovering) slider,
.nautilus-window placessidebar.sidebar scrollbar.overlay-indicator:not(.dragging):not(.hovering) slider, .nemo-window .sidebar scrollbar.overlay-indicator:not(.dragging):not(.hovering) slider, .caja-side-pane scrollbar.overlay-indicator:not(.dragging):not(.hovering) slider {
    background-color: #e7eaee;
    border: 1px solid rgba(0, 0, 0, 0.3); }
filechooser placessidebar.sidebar scrollbar slider,
.nautilus-window placessidebar.sidebar scrollbar slider, .nemo-window .sidebar scrollbar slider, .caja-side-pane scrollbar slider {
    background-color: rgba(231, 234, 238, 0.7); }
filechooser placessidebar.sidebar scrollbar slider:hover,
.nautilus-window placessidebar.sidebar scrollbar slider:hover, .nemo-window .sidebar scrollbar slider:hover, .caja-side-pane scrollbar slider:hover {
    background-color: #f6f7f9; }
filechooser placessidebar.sidebar scrollbar slider:hover:active,
.nautilus-window placessidebar.sidebar scrollbar slider:hover:active, .nemo-window .sidebar scrollbar slider:hover:active, .caja-side-pane scrollbar slider:hover:active {
    background-color: @theme_selected_bg_color; }
filechooser placessidebar.sidebar scrollbar slider:disabled,
.nautilus-window placessidebar.sidebar scrollbar slider:disabled, .nemo-window .sidebar scrollbar slider:disabled, .caja-side-pane scrollbar slider:disabled {
    background-color: transparent; }
filechooser placessidebar.sidebar scrollbar trough,
.nautilus-window placessidebar.sidebar scrollbar trough, .nemo-window .sidebar scrollbar trough, .caja-side-pane scrollbar trough {
    background-color: rgba(42, 45, 55, 0.95); }



@define-color insensitive_base_color @theme_bg_color;
@define-color theme_unfocused_fg_color #D3DAE3;
@define-color theme_unfocused_text_color #D3DAE3;
@define-color theme_unfocused_bg_color #383C4A;
@define-color theme_unfocused_base_color @theme_bg_color;
@define-color borders #2b2e39;
@define-color unfocused_borders #2b2e39;
@define-color warning_color #F27835;
@define-color error_color #FC4138;
@define-color success_color #73d216;
@define-color placeholder_text_color #A8A8A8;
@define-color link_color #e4a5a8;
@define-color content_view_bg @theme_bg_color;
@define-color wm_title alpha(#cfdae7, 0.8);
@define-color wm_unfocused_title alpha(#cfdae7, 0.5);
@define-color wm_bg #2f343f;
@define-color wm_bg_unfocused #323843;
@define-color wm_highlight #363b48;
@define-color wm_shadow alpha(black, 0.35);
@define-color wm_button_close_bg @theme_selected_bg_color;
@define-color wm_button_close_hover_bg #d7787d;
@define-color wm_button_close_active_bg #be3841;
@define-color wm_icon_close_bg #2f343f;
@define-color wm_button_hover_bg #454C5C;
@define-color wm_button_active_bg @theme_selected_bg_color;
@define-color wm_button_hover_border #262932;
@define-color wm_icon_bg #90939B;
@define-color wm_icon_unfocused_bg #666A74;
@define-color wm_icon_hover_bg #C4C7CC;
@define-color wm_icon_active_bg #ffffff;

/* dark colormap */

@define-color theme_base_color #060A0F;
@define-color theme_text_color #6EBEFE;
@define-color theme_bg_color #232323;
@define-color theme_fg_color @theme_text_color;
@define-color selected_bg_color #0D377C;
@define-color selected_fg_color #ffffff;
@define-color theme_selected_bg_color @selected_bg_color;

@define-color menu_bg_color #555753;
@define-color menu_fg_color @theme_text_color;

@define-color menu_combobox_border @theme_selected_bg_color;
@define-color menu_separator mix (@theme_bg_color, @menu_bg_color, 0.90);

@define-color theme_tooltip_bg_color #000000;
@define-color theme_tooltip_fg_color #eeeeee;


@define-color button_border #24282a;

@define-color button_raised_linked_shadow alpha(#000000, 0.14);


@define-color insensitive_bg_color alpha(#0b0b0d, 0.0);
@define-color insensitive_fg_color alpha(#717171, 0.50);
@define-color insensitive_border_color alpha(#717171, 0.50);

@define-color inactive_frame_color shade (@theme_bg_color, 0.8);

@define-color notebook_border @button_border;


@define-color switch_slider_color #111113;
@define-color switch_slider_border #a5b8cc;

@define-color highlighted_border @button_border;
@define-color internal_element_color #888a85;
@define-color internal_element_prelight #333333;

@define-color progressbar_background #030303;
@define-color progressbar_border #3D3D3D;

@define-color progressbar_background_a #00455F;
@define-color progressbar_background_b #0082B2;
@define-color progressbar_pattern #000000;

@define-color entry_text_color #6EBEFE;
@define-color entry_background_a #848684;
@define-color entry_background_b #babcba;
@define-color entry_background_c #e7e8e7;
@define-color entry_background_d #f3f3f3;

@define-color frame_color #707070;


@define-color toolbar_gradient_base #484848;
@define-color toolbar_gradient_step1 #383838;
@define-color toolbar_gradient_step2 #2F2F2F;
@define-color toolbar_gradient_final #000000;

@define-color toolbar_active_button_color #06439C;
@define-color toolbar_border_top #050505;
@define-color toolbar_border_bottom #595959;

@define-color primary_toolbar_entry_bg #060A0F;
@define-color primary_toolbar_entry_fg @theme_text_color;



@define-color menu_controls_color #aaa8ac;


@define-color trough_bg_color_a #252525;
@define-color trough_bg_color_b #41433f;




/* FIXME: needs dark colors from here */
@define-color link_color #4a90d9;
@define-color warning_color #f57900;
@define-color error_color #cc0000;
@define-color success_color #4e9a06;

@define-color info_fg_color rgb (181, 171, 156);
@define-color info_bg_color rgb (252, 252, 189);
@define-color warning_fg_color rgb (173, 120, 41);
@define-color warning_bg_color rgb (250, 173, 61);
@define-color question_fg_color rgb (97, 122, 214);
@define-color question_bg_color rgb (138, 173, 212);
@define-color error_fg_color rgb (166, 38, 38);
@define-color error_bg_color rgb (237, 54, 54);

@define-color os_chrome_bg_color black;
@define-color os_chrome_fg_color #ccc;
@define-color os_chrome_selected_bg_color #333;
@define-color os_chrome_selected_fg_color white;

@define-color chrome_bg_color #1e1a17;
@define-color chrome_fg_color #fff;

@define-color scale_progress_fill #2c85e2;
@define-color scale_progress_border #1864b2;
@define-color scale_progress_border_b #3e90e5;

@define-color wm_title_highlight #111111;
@define-color wm_shadow #000000;

@define-color osd_text_shadow #000000;
@define-color window_frame #7C7C7C;
@define-color window_frame_inactive #3E3E3E;

